@@ -1,10 +1,13 @@
 package Monitoring::GLPlugin::SNMP::MibsAndOids::CHECKPOINTMIB;
 
 $Monitoring::GLPlugin::SNMP::MibsAndOids::origin->{'CHECKPOINT-MIB'} = {
-  'url' => 'https://supportcenter.checkpoint.com/supportcenter/portal/user/anon/page/default.psml/media-type/html?action=portlets.DCFileAction&eventSubmit_doGetdcdetails=&fileid=42272',
-  'name' => 'CHECKPOINT-MIB',
+  url => '',
+  name => 'CHECKPOINT-MIB',
 };
 
+$Monitoring::GLPlugin::SNMP::MibsAndOids::mib_ids->{'CHECKPOINT-MIB'} =
+    '1.3.6.1.4.1.2620.1';
+
 $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'CHECKPOINT-MIB'} = {
   'checkpoint' => '1.3.6.1.4.1.2620',
   'products' => '1.3.6.1.4.1.2620.1',
@@ -50,20 +53,6 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'CHECKPOINT-MIB'} = {
   'fwDroppedBytesTotalRate' => '1.3.6.1.4.1.2620.1.1.25.9',
   'fwConnTableLimit' => '1.3.6.1.4.1.2620.1.1.25.10',
   'fwDroppedTotalRate' => '1.3.6.1.4.1.2620.1.1.25.16',
-  'fwIfTable64' => '1.3.6.1.4.1.2620.1.1.25.25',
-  'fwIfEntry64' => '1.3.6.1.4.1.2620.1.1.25.25.1',
-  'fwIfIndex64' => '1.3.6.1.4.1.2620.1.1.25.25.1.1',
-  'fwIfName64' => '1.3.6.1.4.1.2620.1.1.25.25.1.2',
-  'fwAcceptPcktsIn64' => '1.3.6.1.4.1.2620.1.1.25.25.1.5',
-  'fwAcceptPcktsOut64' => '1.3.6.1.4.1.2620.1.1.25.25.1.6',
-  'fwAcceptBytesIn64' => '1.3.6.1.4.1.2620.1.1.25.25.1.7',
-  'fwAcceptBytesOut64' => '1.3.6.1.4.1.2620.1.1.25.25.1.8',
-  'fwDropPcktsIn64' => '1.3.6.1.4.1.2620.1.1.25.25.1.9',
-  'fwDropPcktsOut64' => '1.3.6.1.4.1.2620.1.1.25.25.1.10',
-  'fwRejectPcktsIn64' => '1.3.6.1.4.1.2620.1.1.25.25.1.11',
-  'fwRejectPcktsOut64' => '1.3.6.1.4.1.2620.1.1.25.25.1.12',
-  'fwLogIn64' => '1.3.6.1.4.1.2620.1.1.25.25.1.13',
-  'fwLogOut64' => '1.3.6.1.4.1.2620.1.1.25.25.1.14',
   'fwPerfStat' => '1.3.6.1.4.1.2620.1.1.26',
   'fwHmem' => '1.3.6.1.4.1.2620.1.1.26.1',
   'fwHmem-block-size' => '1.3.6.1.4.1.2620.1.1.26.1.1',
@@ -431,8 +420,11 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'CHECKPOINT-MIB'} = {
   'fwLSConnName' => '1.3.6.1.4.1.2620.1.1.30.3.1.2',
   'fwLSConnState' => '1.3.6.1.4.1.2620.1.1.30.3.1.3',
   'fwLSConnStateDesc' => '1.3.6.1.4.1.2620.1.1.30.3.1.4',
+  'fwLSConnSendRate' => '1.3.6.1.4.1.2620.1.1.30.3.1.5',
   'fwLocalLoggingDesc' => '1.3.6.1.4.1.2620.1.1.30.4',
   'fwLocalLoggingStat' => '1.3.6.1.4.1.2620.1.1.30.5',
+  'fwLocalLoggingWriteRate' => '1.3.6.1.4.1.2620.1.1.30.6',
+  'fwLoggingHandlingRate' => '1.3.6.1.4.1.2620.1.1.30.7',
   'vpn' => '1.3.6.1.4.1.2620.1.2',
   'cpvProdName' => '1.3.6.1.4.1.2620.1.2.1',
   'cpvVerMajor' => '1.3.6.1.4.1.2620.1.2.2',
@@ -799,6 +791,46 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'CHECKPOINT-MIB'} = {
   'svnApplianceSerialNumber' => '1.3.6.1.4.1.2620.1.6.16.3',
   'svnApplianceProductName' => '1.3.6.1.4.1.2620.1.6.16.7',
   'svnApplianceManufacturer' => '1.3.6.1.4.1.2620.1.6.16.9',
+  'svnApplianceSeriesString' => '1.3.6.1.4.1.2620.1.6.16.10',
+  'svnLicensing' => '1.3.6.1.4.1.2620.1.6.18',
+  'licensingTable' => '1.3.6.1.4.1.2620.1.6.18.1',
+  'licensingEntry' => '1.3.6.1.4.1.2620.1.6.18.1.1',
+  'licensingIndex' => '1.3.6.1.4.1.2620.1.6.18.1.1.1',
+  'licensingID' => '1.3.6.1.4.1.2620.1.6.18.1.1.2',
+  'licensingBladeName' => '1.3.6.1.4.1.2620.1.6.18.1.1.3',
+  'licensingState' => '1.3.6.1.4.1.2620.1.6.18.1.1.4',
+  'licensingExpirationDate' => '1.3.6.1.4.1.2620.1.6.18.1.1.5',
+  'licensingImpact' => '1.3.6.1.4.1.2620.1.6.18.1.1.6',
+  'licensingBladeActive' => '1.3.6.1.4.1.2620.1.6.18.1.1.7',
+  'licensingTotalQuota' => '1.3.6.1.4.1.2620.1.6.18.1.1.8',
+  'licensingUsedQuota' => '1.3.6.1.4.1.2620.1.6.18.1.1.9',
+  'licensingAssetInfo' => '1.3.6.1.4.1.2620.1.6.18.2',
+  'licensingAssetAccountId' => '1.3.6.1.4.1.2620.1.6.18.2.1',
+  'licensingAssetPackageDescription' => '1.3.6.1.4.1.2620.1.6.18.2.2',
+  'licensingAssetContainerCK' => '1.3.6.1.4.1.2620.1.6.18.2.3',
+  'licensingAssetContainerSKU' => '1.3.6.1.4.1.2620.1.6.18.2.4',
+  'licensingAssetSupportLevel' => '1.3.6.1.4.1.2620.1.6.18.2.5',
+  'licensingAssetSupportExpiration' => '1.3.6.1.4.1.2620.1.6.18.2.6',
+  'licensingAssetActivationStatus' => '1.3.6.1.4.1.2620.1.6.18.2.7',
+  'svnConnectivity' => '1.3.6.1.4.1.2620.1.6.19',
+  'svnUpdatesInfo' => '1.3.6.1.4.1.2620.1.6.20',
+  'svnUpdatesInfoBuild' => '1.3.6.1.4.1.2620.1.6.20.1',
+  'svnUpdatesInfoStatus' => '1.3.6.1.4.1.2620.1.6.20.2',
+  'svnUpdatesInfoConnection' => '1.3.6.1.4.1.2620.1.6.20.3',
+  'svnUpdatesInfoAvailablePackages' => '1.3.6.1.4.1.2620.1.6.20.4',
+  'svnUpdatesInfoAvailableRecommended' => '1.3.6.1.4.1.2620.1.6.20.5',
+  'svnUpdatesInfoAvailableHotfixes' => '1.3.6.1.4.1.2620.1.6.20.6',
+  'updatesInstalledTable' => '1.3.6.1.4.1.2620.1.6.20.7',
+  'updatesInstalledEntry' => '1.3.6.1.4.1.2620.1.6.20.7.1',
+  'updatesInstalledIndex' => '1.3.6.1.4.1.2620.1.6.20.7.1.1',
+  'updatesInstalledName' => '1.3.6.1.4.1.2620.1.6.20.7.1.2',
+  'updatesInstalledType' => '1.3.6.1.4.1.2620.1.6.20.7.1.3',
+  'updatesRecommendedTable' => '1.3.6.1.4.1.2620.1.6.20.8',
+  'updatesRecommendedEntry' => '1.3.6.1.4.1.2620.1.6.20.8.1',
+  'updatesRecommendedIndex' => '1.3.6.1.4.1.2620.1.6.20.8.1.1',
+  'updatesRecommendedName' => '1.3.6.1.4.1.2620.1.6.20.8.1.2',
+  'updatesRecommendedType' => '1.3.6.1.4.1.2620.1.6.20.8.1.3',
+  'updatesRecommendedStatus' => '1.3.6.1.4.1.2620.1.6.20.8.1.4',
   'svnNetStat' => '1.3.6.1.4.1.2620.1.6.50',
   'svnNetIfTable' => '1.3.6.1.4.1.2620.1.6.50.1',
   'svnNetIfTableEntry' => '1.3.6.1.4.1.2620.1.6.50.1.1',
@@ -812,14 +844,6 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'CHECKPOINT-MIB'} = {
   'svnNetIfMAC' => '1.3.6.1.4.1.2620.1.6.50.1.1.8',
   'svnNetIfDescription' => '1.3.6.1.4.1.2620.1.6.50.1.1.9',
   'svnNetIfOperState' => '1.3.6.1.4.1.2620.1.6.50.1.1.10',
-  'svnNetIfRXBytes' => '1.3.6.1.4.1.2620.1.6.50.1.1.13',
-  'svnNetIfRXDrops' => '1.3.6.1.4.1.2620.1.6.50.1.1.14',
-  'svnNetIfRXErrors' => '1.3.6.1.4.1.2620.1.6.50.1.1.15',
-  'svnNetIfRXPackets' => '1.3.6.1.4.1.2620.1.6.50.1.1.16',
-  'svnNetIfTXBytes' => '1.3.6.1.4.1.2620.1.6.50.1.1.17',
-  'svnNetIfTXDrops' => '1.3.6.1.4.1.2620.1.6.50.1.1.18',
-  'svnNetIfTXErrors' => '1.3.6.1.4.1.2620.1.6.50.1.1.19',
-  'svnNetIfTXPackets' => '1.3.6.1.4.1.2620.1.6.50.1.1.20',
   'vsRoutingTable' => '1.3.6.1.4.1.2620.1.6.51',
   'vsRoutingEntry' => '1.3.6.1.4.1.2620.1.6.51.1',
   'vsRoutingIndex' => '1.3.6.1.4.1.2620.1.6.51.1.1',
@@ -904,9 +928,32 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'CHECKPOINT-MIB'} = {
   'mgClientHost' => '1.3.6.1.4.1.2620.1.7.7.1.3',
   'mgClientDbLock' => '1.3.6.1.4.1.2620.1.7.7.1.4',
   'mgApplicationType' => '1.3.6.1.4.1.2620.1.7.7.1.5',
-  'mgMgmtHAJournals' => '1.3.6.1.4.1.2620.1.7.9',
-  'mgIsLicenseViolation' => '1.3.6.1.4.1.2620.1.7.10',
-  'mgLicenseViolationMsg' => '1.3.6.1.4.1.2620.1.7.11',
+  'mgLogServerInfo' => '1.3.6.1.4.1.2620.1.7.14',
+  'mgLSLogReceiveRate' => '1.3.6.1.4.1.2620.1.7.14.1',
+  'mgLSLogReceiveRatePeak' => '1.3.6.1.4.1.2620.1.7.14.2',
+  'mgLSLogReceiveRate10Min' => '1.3.6.1.4.1.2620.1.7.14.3',
+  'mgConnectedGatewaysTable' => '1.3.6.1.4.1.2620.1.7.14.4',
+  'mgConnectedGatewaysEntry' => '1.3.6.1.4.1.2620.1.7.14.4.1',
+  'mglsGWIndex' => '1.3.6.1.4.1.2620.1.7.14.4.1.1',
+  'mglsGWIP' => '1.3.6.1.4.1.2620.1.7.14.4.1.2',
+  'mglsGWState' => '1.3.6.1.4.1.2620.1.7.14.4.1.3',
+  'mglsGWLastLoginTime' => '1.3.6.1.4.1.2620.1.7.14.4.1.4',
+  'mglsGWLogReceiveRate' => '1.3.6.1.4.1.2620.1.7.14.4.1.5',
+  'mgIndexerInfo' => '1.3.6.1.4.1.2620.1.7.14.5',
+  'mgIndexerInfoTotalReadLogs' => '1.3.6.1.4.1.2620.1.7.14.5.1',
+  'mgIndexerInfoTotalUpdatesAndLogsIndexed' => '1.3.6.1.4.1.2620.1.7.14.5.2',
+  'mgIndexerInfoTotalReadLogsErrors' => '1.3.6.1.4.1.2620.1.7.14.5.3',
+  'mgIndexerInfoTotalUpdatesAndLogsIndexedErrors' => '1.3.6.1.4.1.2620.1.7.14.5.4',
+  'mgIndexerInfoUpdatesAndLogsIndexedRate' => '1.3.6.1.4.1.2620.1.7.14.5.5',
+  'mgIndexerInfoReadLogsRate' => '1.3.6.1.4.1.2620.1.7.14.5.6',
+  'mgIndexerInfoUpdatesAndLogsIndexedRate10min' => '1.3.6.1.4.1.2620.1.7.14.5.7',
+  'mgIndexerInfoReadLogsRate10min' => '1.3.6.1.4.1.2620.1.7.14.5.8',
+  'mgIndexerInfoUpdatesAndLogsIndexedRate60min' => '1.3.6.1.4.1.2620.1.7.14.5.9',
+  'mgIndexerInfoReadLogsRate60min' => '1.3.6.1.4.1.2620.1.7.14.5.10',
+  'mgIndexerInfoUpdatesAndLogsIndexedRatePeak' => '1.3.6.1.4.1.2620.1.7.14.5.11',
+  'mgIndexerInfoReadLogsRatePeak' => '1.3.6.1.4.1.2620.1.7.14.5.12',
+  'mgIndexerInfoReadLogsDelay' => '1.3.6.1.4.1.2620.1.7.14.5.13',
+  'mgLSLogReceiveRate1Hour' => '1.3.6.1.4.1.2620.1.7.14.6',
   'mgStatCode' => '1.3.6.1.4.1.2620.1.7.101',
   'mgStatShortDescr' => '1.3.6.1.4.1.2620.1.7.102',
   'mgStatLongDescr' => '1.3.6.1.4.1.2620.1.7.103',
@@ -956,6 +1003,27 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'CHECKPOINT-MIB'} = {
   'lsClientHost' => '1.3.6.1.4.1.2620.1.11.7.1.3',
   'lsClientDbLock' => '1.3.6.1.4.1.2620.1.11.7.1.4',
   'lsApplicationType' => '1.3.6.1.4.1.2620.1.11.7.1.5',
+  'lsLoggingInfo' => '1.3.6.1.4.1.2620.1.11.14',
+  'lsLogReceiveRate' => '1.3.6.1.4.1.2620.1.11.14.1',
+  'lsLogReceiveRatePeak' => '1.3.6.1.4.1.2620.1.11.14.2',
+  'lsLogReceiveRate10Min' => '1.3.6.1.4.1.2620.1.11.14.3',
+  'lsConnectedGatewaysTable' => '1.3.6.1.4.1.2620.1.11.14.4',
+  'lsConnectedGatewaysEntry' => '1.3.6.1.4.1.2620.1.11.14.4.1',
+  'lsGWIndex' => '1.3.6.1.4.1.2620.1.11.14.4.1.1',
+  'lsGWIP' => '1.3.6.1.4.1.2620.1.11.14.4.1.2',
+  'lsGWState' => '1.3.6.1.4.1.2620.1.11.14.4.1.3',
+  'lsGWLastLoginTime' => '1.3.6.1.4.1.2620.1.11.14.4.1.4',
+  'lsGWLogReceiveRate' => '1.3.6.1.4.1.2620.1.11.14.4.1.5',
+  'lsIndexerInfo' => '1.3.6.1.4.1.2620.1.11.14.5',
+  'lsIndexerInfoTotalReadLogs' => '1.3.6.1.4.1.2620.1.11.14.5.1',
+  'lsIndexerInfoTotalUpdatesAndLogsIndexed' => '1.3.6.1.4.1.2620.1.11.14.5.2',
+  'lsIndexerInfoTotalReadLogsErrors' => '1.3.6.1.4.1.2620.1.11.14.5.3',
+  'lsIndexerInfoTotalUpdatesAndLogsIndexedErrors' => '1.3.6.1.4.1.2620.1.11.14.5.4',
+  'lsIndexerInfoUpdatesAndLogsIndexedRate' => '1.3.6.1.4.1.2620.1.11.14.5.5',
+  'lsIndexerInfoReadLogsRate' => '1.3.6.1.4.1.2620.1.11.14.5.6',
+  'lsIndexerInfoUpdatesAndLogsIndexedRatePeak' => '1.3.6.1.4.1.2620.1.11.14.5.7',
+  'lsIndexerInfoReadLogsRatePeak' => '1.3.6.1.4.1.2620.1.11.14.5.8',
+  'lsLogReceiveRate1Hour' => '1.3.6.1.4.1.2620.1.11.14.6',
   'lsStatCode' => '1.3.6.1.4.1.2620.1.11.101',
   'lsStatShortDescr' => '1.3.6.1.4.1.2620.1.11.102',
   'lsStatLongDescr' => '1.3.6.1.4.1.2620.1.11.103',
@@ -1000,7 +1068,6 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'CHECKPOINT-MIB'} = {
   'vsxCountersBytesRejectedTotal' => '1.3.6.1.4.1.2620.1.16.23.1.1.11',
   'vsxCountersLoggedTotal' => '1.3.6.1.4.1.2620.1.16.23.1.1.12',
   'vsxCountersIsDataValid' => '1.3.6.1.4.1.2620.1.16.23.1.1.13',
-  'vsxCountersIsDataValidDefinition' => 'CHECKPOINT-MIB::vsxCountersIsDataValid',
   'smartDefense' => '1.3.6.1.4.1.2620.1.17',
   'asmAttacks' => '1.3.6.1.4.1.2620.1.17.1',
   'asmLayer3' => '1.3.6.1.4.1.2620.1.17.1.1',
@@ -1061,110 +1128,6 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'CHECKPOINT-MIB'} = {
   'numOfP2PSkypeCon' => '1.3.6.1.4.1.2620.1.17.1.3.3.5.1',
   'asmP2PBitTorrentCon' => '1.3.6.1.4.1.2620.1.17.1.3.3.6',
   'numOfBitTorrentCon' => '1.3.6.1.4.1.2620.1.17.1.3.3.6.1',
-  'gx' => '1.3.6.1.4.1.2620.1.20',
-  'gxInfo' => '1.3.6.1.4.1.2620.1.20.1',
-  'gxProdName' => '1.3.6.1.4.1.2620.1.20.1.1',
-  'gxProdVersion' => '1.3.6.1.4.1.2620.1.20.1.2',
-  'gxProdVerMajor' => '1.3.6.1.4.1.2620.1.20.2',
-  'gxProdVerMinor' => '1.3.6.1.4.1.2620.1.20.3',
-  'gxBuild' => '1.3.6.1.4.1.2620.1.20.4',
-  'gxCreateInfo' => '1.3.6.1.4.1.2620.1.20.5',
-  'gxCreateSinceInstall' => '1.3.6.1.4.1.2620.1.20.5.1',
-  'gxActContxt' => '1.3.6.1.4.1.2620.1.20.5.2',
-  'gxDropPlicyCreate' => '1.3.6.1.4.1.2620.1.20.5.3',
-  'gxDropMalformedReqCreate' => '1.3.6.1.4.1.2620.1.20.5.4',
-  'gxDropMalformedRespCreate' => '1.3.6.1.4.1.2620.1.20.5.5',
-  'gxExpiredCreate' => '1.3.6.1.4.1.2620.1.20.5.6',
-  'gxBadCauseCreate' => '1.3.6.1.4.1.2620.1.20.5.7',
-  'gxSecondaryNsapiEntries' => '1.3.6.1.4.1.2620.1.20.5.8',
-  'gxActv0v1PdnConns' => '1.3.6.1.4.1.2620.1.20.5.11',
-  'gxTunnelApnsEntries' => '1.3.6.1.4.1.2620.1.20.5.12',
-  'gxTunnelsEntries' => '1.3.6.1.4.1.2620.1.20.5.13',
-  'gxDeleteInfo' => '1.3.6.1.4.1.2620.1.20.6',
-  'gxDeleteSinceInstall' => '1.3.6.1.4.1.2620.1.20.6.1',
-  'gxDropOutOfContxtDelete' => '1.3.6.1.4.1.2620.1.20.6.2',
-  'gxDropMalformedReqDelete' => '1.3.6.1.4.1.2620.1.20.6.3',
-  'gxDropMalformedRespDelete' => '1.3.6.1.4.1.2620.1.20.6.4',
-  'gxExpiredDelete' => '1.3.6.1.4.1.2620.1.20.6.5',
-  'gxBadCauseDelete' => '1.3.6.1.4.1.2620.1.20.6.6',
-  'gxUpdateInfo' => '1.3.6.1.4.1.2620.1.20.7',
-  'gxUpdateSinceInstall' => '1.3.6.1.4.1.2620.1.20.7.1',
-  'gxDropOutOfContxtUpdate' => '1.3.6.1.4.1.2620.1.20.7.2',
-  'gxDropMalformedReqUpdate' => '1.3.6.1.4.1.2620.1.20.7.3',
-  'gxDropMalformedRespUpdate' => '1.3.6.1.4.1.2620.1.20.7.4',
-  'gxExpiredUpdate' => '1.3.6.1.4.1.2620.1.20.7.5',
-  'gxBadCauseUpdate' => '1.3.6.1.4.1.2620.1.20.7.6',
-  'gxPathMngInfo' => '1.3.6.1.4.1.2620.1.20.8',
-  'gxEchoSinceInstall' => '1.3.6.1.4.1.2620.1.20.8.1',
-  'gxVnspSinceInstall' => '1.3.6.1.4.1.2620.1.20.8.2',
-  'gxDropPolicyEcho' => '1.3.6.1.4.1.2620.1.20.8.3',
-  'gxDropMalformedReqEcho' => '1.3.6.1.4.1.2620.1.20.8.4',
-  'gxDropMalformedRespEcho' => '1.3.6.1.4.1.2620.1.20.8.5',
-  'gxExpiredEcho' => '1.3.6.1.4.1.2620.1.20.8.6',
-  'gxDropVnsp' => '1.3.6.1.4.1.2620.1.20.8.7',
-  'gxGtpPathEntries' => '1.3.6.1.4.1.2620.1.20.8.8',
-  'gxGpduInfo' => '1.3.6.1.4.1.2620.1.20.9',
-  'gxGpdu1MinAvgRate' => '1.3.6.1.4.1.2620.1.20.9.1',
-  'gxDropOutOfContxtGpdu' => '1.3.6.1.4.1.2620.1.20.9.2',
-  'gxDropAnti-spoofingGpdu' => '1.3.6.1.4.1.2620.1.20.9.3',
-  'gxDropMs-MsGpdu' => '1.3.6.1.4.1.2620.1.20.9.4',
-  'gxDropBadSeqGpdu' => '1.3.6.1.4.1.2620.1.20.9.5',
-  'gxDropBadGpdu' => '1.3.6.1.4.1.2620.1.20.9.6',
-  'gxGpduExpiredTunnel' => '1.3.6.1.4.1.2620.1.20.9.7',
-  'gxInitiateInfo' => '1.3.6.1.4.1.2620.1.20.10',
-  'gxInitiateSinceInstall' => '1.3.6.1.4.1.2620.1.20.10.1',
-  'gxDropInitiationReq' => '1.3.6.1.4.1.2620.1.20.10.2',
-  'gxDropInitiationResp' => '1.3.6.1.4.1.2620.1.20.10.3',
-  'gxExpiredInitiateAct' => '1.3.6.1.4.1.2620.1.20.10.4',
-  'gxGTPv2CreateInfo' => '1.3.6.1.4.1.2620.1.20.11',
-  'gxGTPv2CreateSessionSinceInstall' => '1.3.6.1.4.1.2620.1.20.11.1',
-  'gxGTPv2CreateBearerSinceInstall' => '1.3.6.1.4.1.2620.1.20.11.2',
-  'gxGTPv2ExpiredCreateSession' => '1.3.6.1.4.1.2620.1.20.11.3',
-  'gxGTPv2ExpiredCreateBearer' => '1.3.6.1.4.1.2620.1.20.11.4',
-  'gxGTPv2DropMalformedCreateSessionReq' => '1.3.6.1.4.1.2620.1.20.11.5',
-  'gxGTPv2DropMalformedCreateSessionResp' => '1.3.6.1.4.1.2620.1.20.11.6',
-  'gxGTPv2DropMalformedCreateBearerReq' => '1.3.6.1.4.1.2620.1.20.11.7',
-  'gxGTPv2DropMalformedCreateBearerResp' => '1.3.6.1.4.1.2620.1.20.11.8',
-  'gxGTPv2DropPolicyCreateSession' => '1.3.6.1.4.1.2620.1.20.11.9',
-  'gxGTPv2DropPolicyCreateBearer' => '1.3.6.1.4.1.2620.1.20.11.10',
-  'gxGTPv2ActPDN' => '1.3.6.1.4.1.2620.1.20.11.11',
-  'gxGTPv2ActDataBearers' => '1.3.6.1.4.1.2620.1.20.11.12',
-  'gxGTPv2DeleteInfo' => '1.3.6.1.4.1.2620.1.20.12',
-  'gxGTPv2DeleteSessionSinceInstall' => '1.3.6.1.4.1.2620.1.20.12.1',
-  'gxGTPv2DeleteBearerSinceInstall' => '1.3.6.1.4.1.2620.1.20.12.2',
-  'gxGTPv2ExpiredDeleteSession' => '1.3.6.1.4.1.2620.1.20.12.3',
-  'gxGTPv2ExpiredDeleteBearer' => '1.3.6.1.4.1.2620.1.20.12.4',
-  'gxGTPv2DropMalformedDeleteSessionReq' => '1.3.6.1.4.1.2620.1.20.12.5',
-  'gxGTPv2DropMalformedDeleteSessionResp' => '1.3.6.1.4.1.2620.1.20.12.6',
-  'gxGTPv2DropMalformedDeleteBearerReq' => '1.3.6.1.4.1.2620.1.20.12.7',
-  'gxGTPv2DropMalformedDeleteBearerResp' => '1.3.6.1.4.1.2620.1.20.12.8',
-  'gxGTPv2DropPolicyDeleteSession' => '1.3.6.1.4.1.2620.1.20.12.9',
-  'gxGTPv2DropPolicyDeleteBearer' => '1.3.6.1.4.1.2620.1.20.12.10',
-  'gxGTPv2UpdateInfo' => '1.3.6.1.4.1.2620.1.20.13',
-  'gxGTPv2UpdateBearerSinceInstall' => '1.3.6.1.4.1.2620.1.20.13.1',
-  'gxGTPv2ExpiredUpdateBearer' => '1.3.6.1.4.1.2620.1.20.13.2',
-  'gxGTPv2ModifyBearerSinceInstall' => '1.3.6.1.4.1.2620.1.20.13.3',
-  'gxGTPv2ExpiredModifyBearer' => '1.3.6.1.4.1.2620.1.20.13.4',
-  'gxGTPv2DropMalformedUpdateBearerReq' => '1.3.6.1.4.1.2620.1.20.13.5',
-  'gxGTPv2DropMalformedUpdateBearerResp' => '1.3.6.1.4.1.2620.1.20.13.6',
-  'gxGTPv2DropMalformedModifyBearerReq' => '1.3.6.1.4.1.2620.1.20.13.7',
-  'gxGTPv2DropMalformedModifyBearerResp' => '1.3.6.1.4.1.2620.1.20.13.8',
-  'gxGTPv2DropPolicyUpdateBearer' => '1.3.6.1.4.1.2620.1.20.13.9',
-  'gxGTPv2DropPolicyModifyBearer' => '1.3.6.1.4.1.2620.1.20.13.10',
-  'gxGTPv2PathMngInfo' => '1.3.6.1.4.1.2620.1.20.14',
-  'gxGTPv2EchoSinceInstall' => '1.3.6.1.4.1.2620.1.20.14.1',
-  'gxGTPv2VnspSinceInstall' => '1.3.6.1.4.1.2620.1.20.14.2',
-  'gxGTPv2ExpiredEcho' => '1.3.6.1.4.1.2620.1.20.14.3',
-  'gxGTPv2DropMalformedEchoReq' => '1.3.6.1.4.1.2620.1.20.14.4',
-  'gxGTPv2DropMalformedEchoResp' => '1.3.6.1.4.1.2620.1.20.14.5',
-  'gxGTPv2DropPolicyEcho' => '1.3.6.1.4.1.2620.1.20.14.6',
-  'gxGTPv2CmdInfo' => '1.3.6.1.4.1.2620.1.20.15',
-  'gxGTPv2ModifyBearerCmdSinceInstall' => '1.3.6.1.4.1.2620.1.20.15.1',
-  'gxGTPv2ModifyBearerFailIndSinceInstall' => '1.3.6.1.4.1.2620.1.20.15.2',
-  'gxGTPv2DeleteBearerCmdSinceInstall' => '1.3.6.1.4.1.2620.1.20.15.3',
-  'gxGTPv2DeleteBearerFailIndSinceInstall' => '1.3.6.1.4.1.2620.1.20.15.4',
-  'gxGTPv2BearerResourceCmdSinceInstall' => '1.3.6.1.4.1.2620.1.20.15.5',
-  'gxGTPv2BearerResourceFailIndSinceInstall' => '1.3.6.1.4.1.2620.1.20.15.6',
   'avi' => '1.3.6.1.4.1.2620.1.24',
   'aviEngines' => '1.3.6.1.4.1.2620.1.24.1',
   'aviEngineTable' => '1.3.6.1.4.1.2620.1.24.1.1',
@@ -1479,7 +1442,8 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'CHECKPOINT-MIB'} = {
   'advancedUrlFilteringStatusLongDesc' => '1.3.6.1.4.1.2620.1.43.103',
   'dlp' => '1.3.6.1.4.1.2620.1.44',
   'exchangeAgents' => '1.3.6.1.4.1.2620.1.44.1',
-  'exchangeAgentsTable' => '1.3.6.1.4.1.2620.1.44.1.1',
+  #'exchangeAgentsTable' => '1.3.6.1.4.1.2620.1.44.1.1',
+  'exchangeAgentsStatusTable' => '1.3.6.1.4.1.2620.1.44.1.1',
   'exchangeAgentsStatusEntry' => '1.3.6.1.4.1.2620.1.44.1.1.1',
   'exchangeAgentsStatusTableIndex' => '1.3.6.1.4.1.2620.1.44.1.1.1.1',
   'exchangeAgentName' => '1.3.6.1.4.1.2620.1.44.1.1.1.2',
@@ -1564,18 +1528,6 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'CHECKPOINT-MIB'} = {
   'teStatusCode' => '1.3.6.1.4.1.2620.1.49.101',
   'teStatusShortDesc' => '1.3.6.1.4.1.2620.1.49.102',
   'teStatusLongDesc' => '1.3.6.1.4.1.2620.1.49.103',
-  'treatExtarction' => '1.3.6.1.4.1.2620.1.50',
-  'treatExtarctionSubscription' => '1.3.6.1.4.1.2620.1.50.1',
-  'treatExtarctionSubscriptionStatus' => '1.3.6.1.4.1.2620.1.50.1.1',
-  'treatExtarctionSubscriptionExpDate' => '1.3.6.1.4.1.2620.1.50.1.2',
-  'treatExtarctionSubscriptionDesc' => '1.3.6.1.4.1.2620.1.50.1.3',
-  'treatExtarctionStatistics' => '1.3.6.1.4.1.2620.1.50.2',
-  'treatExtarctionTotalScannedAttachments' => '1.3.6.1.4.1.2620.1.50.2.1',
-  'treatExtarctionCleanedAttachments' => '1.3.6.1.4.1.2620.1.50.2.2',
-  'treatExtarctionOriginalAttachmentsAccesses' => '1.3.6.1.4.1.2620.1.50.2.3',
-  'treatExtarctionStatusCode' => '1.3.6.1.4.1.2620.1.50.101',
-  'treatExtarctionStatusShortDesc' => '1.3.6.1.4.1.2620.1.50.102',
-  'treatExtarctionStatusLongDesc' => '1.3.6.1.4.1.2620.1.50.103',
   'tables' => '1.3.6.1.4.1.2620.500',
   'raUsersTable' => '1.3.6.1.4.1.2620.500.9000',
   'raUsersEntry' => '1.3.6.1.4.1.2620.500.9000.1',
@@ -1631,61 +1583,7 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'CHECKPOINT-MIB'} = {
 };
 
 $Monitoring::GLPlugin::SNMP::MibsAndOids::definitions->{'CHECKPOINT-MIB'} = {
-  'permanentTunnelPeerType' => {
-    '1' => 'regular',
-    '2' => 'daip',
-    '3' => 'robo',
-  },
-  'tunnelProbState' => {
-    '0' => 'unknown',
-    '1' => 'alive',
-    '2' => 'dead',
-  },
-  'tunnelPeerType' => {
-    '1' => 'regular',
-    '2' => 'daip',
-    '3' => 'robo',
-    '4' => 'lsv',
-  },
-  'raTunnelEncAlgorithm' => {
-    '1' => 'espDES',
-    '2' => 'esp3DES',
-    '5' => 'espCAST',
-    '7' => 'esp3IDEA',
-    '9' => 'espNULL',
-    '129' => 'espAES128',
-    '130' => 'espAES256',
-  },
-  'tunnelLinkPriority' => {
-    '0' => 'primary',
-    '1' => 'backup',
-    '2' => 'on-demand',
-  },
-  'permanentTunnelState' => {
-    '3' => 'active',
-    '4' => 'destroy',
-    '129' => 'idle',
-    '130' => 'phase1',
-    '131' => 'down',
-    '132' => 'init',
-  },
-  'vsxCountersIsDataValid' => {
-    '0' => 'invalid',
-    '1' => 'valid',
-  },
-  'fwSXLStatus' => {
-    '0' => 'disabled',
-    '1' => 'enabled',
-  },
-  'tunnelState' => {
-    '3' => 'active',
-    '4' => 'destroy',
-    '129' => 'idle',
-    '130' => 'phase1',
-    '131' => 'down',
-    '132' => 'init',
-  },
-  'raTunnelAuthMethod' => {
+  raTunnelAuthMethod => {
     '1' => 'preshared-key',
     '2' => 'dss-signature',
     '3' => 'rsa-signature',
@@ -1694,7 +1592,35 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::definitions->{'CHECKPOINT-MIB'} = {
     '129' => 'xauth',
     '130' => 'crack',
   },
-  'raUserState' => {
+  tunnelType => {
+    '1' => 'regular',
+    '2' => 'permanent',
+  },
+  permanentTunnelPeerType => {
+    '1' => 'regular',
+    '2' => 'daip',
+    '3' => 'robo',
+  },
+  permanentTunnelProbState => {
+    '0' => 'unknown',
+    '1' => 'alive',
+    '2' => 'dead',
+  },
+  raTunnelEncAlgorithm => {
+    '1' => 'espDES',
+    '2' => 'esp3DES',
+    '5' => 'espCAST',
+    '7' => 'esp3IDEA',
+    '9' => 'espNULL',
+    '129' => 'espAES128',
+    '130' => 'espAES256',
+  },
+  tunnelLinkPriority => {
+    '0' => 'primary',
+    '1' => 'backup',
+    '2' => 'on-demand',
+  },
+  raUserState => {
     '3' => 'active',
     '4' => 'destroy',
     '129' => 'idle',
@@ -1702,18 +1628,39 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::definitions->{'CHECKPOINT-MIB'} = {
     '131' => 'down',
     '132' => 'init',
   },
-  'permanentTunnelLinkPriority' => {
+  permanentTunnelLinkPriority => {
     '0' => 'primary',
     '1' => 'backup',
     '2' => 'on-demand',
   },
-  'permanentTunnelProbState' => {
+  fwSXLStatus => {
+    '0' => 'disabled',
+    '1' => 'enabled',
+  },
+  tunnelPeerType => {
+    '1' => 'regular',
+    '2' => 'daip',
+    '3' => 'robo',
+  },
+  tunnelState => {
+    '3' => 'active',
+    '4' => 'destroy',
+    '129' => 'idle',
+    '130' => 'phase1',
+    '131' => 'down',
+    '132' => 'init',
+  },
+  permanentTunnelState => {
+    '3' => 'active',
+    '4' => 'destroy',
+    '129' => 'idle',
+    '130' => 'phase1',
+    '131' => 'down',
+    '132' => 'init',
+  },
+  tunnelProbState => {
     '0' => 'unknown',
     '1' => 'alive',
     '2' => 'dead',
   },
-  'tunnelType' => {
-    '1' => 'regular',
-    '2' => 'permanent',
-  },
 };
