@@ -5,7 +5,7 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::origin->{'LIEBERT-GP-CONDITIONS-MIB'}
   name => 'LIEBERT-GP-CONDITIONS-MIB',
 };
 
-#$Monitoring::GLPlugin::SNMP::MibsAndOids::mib_ids->{'LIEBERT-GP-CONDITIONS-MIB'} = 
+$Monitoring::GLPlugin::SNMP::MibsAndOids::mib_ids->{'LIEBERT-GP-CONDITIONS-MIB'} = '1.3.6.1.4.1.476.1.42.3.2';
 
 $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'LIEBERT-GP-CONDITIONS-MIB'} = {
   liebertGlobalProductsConditionsModule => '1.3.6.1.4.1.476.1.42.1.3.1',
@@ -18,10 +18,15 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'LIEBERT-GP-CONDITIONS
   lgpConditionLossOfAirflow1 => '1.3.6.1.4.1.476.1.42.3.2.1.5.1',
   lgpConditionLossOfAirflow2 => '1.3.6.1.4.1.476.1.42.3.2.1.5.2',
   lgpConditionLossOfAirflowBlower1 => '1.3.6.1.4.1.476.1.42.3.2.1.5.3',
+  lgpConditionLossOfAirflowAllBlowers => '1.3.6.1.4.1.476.1.42.3.2.1.5.4',
   lgpConditionChangeFilter => '1.3.6.1.4.1.476.1.42.3.2.1.6',
   lgpConditionCompressorHighHeadPressure => '1.3.6.1.4.1.476.1.42.3.2.1.7',
   lgpConditionCompressor1HighHeadPressure => '1.3.6.1.4.1.476.1.42.3.2.1.7.1',
+  lgpConditionCompressor1AHighHeadPressure => '1.3.6.1.4.1.476.1.42.3.2.1.7.1.1',
+  lgpConditionCompressor1BHighHeadPressure => '1.3.6.1.4.1.476.1.42.3.2.1.7.1.2',
   lgpConditionCompressor2HighHeadPressure => '1.3.6.1.4.1.476.1.42.3.2.1.7.2',
+  lgpConditionCompressor2AHighHeadPressure => '1.3.6.1.4.1.476.1.42.3.2.1.7.2.1',
+  lgpConditionCompressor2BHighHeadPressure => '1.3.6.1.4.1.476.1.42.3.2.1.7.2.2',
   lgpConditionCompressor3HighHeadPressure => '1.3.6.1.4.1.476.1.42.3.2.1.7.3',
   lgpConditionCompressor4HighHeadPressure => '1.3.6.1.4.1.476.1.42.3.2.1.7.4',
   lgpConditionCompressorOverload => '1.3.6.1.4.1.476.1.42.3.2.1.8',
@@ -29,8 +34,14 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'LIEBERT-GP-CONDITIONS
   lgpConditionCompressor2Overload => '1.3.6.1.4.1.476.1.42.3.2.1.8.2',
   lgpConditionCompressorShortCycle => '1.3.6.1.4.1.476.1.42.3.2.1.9',
   lgpConditionCompressor1ShortCycle => '1.3.6.1.4.1.476.1.42.3.2.1.9.1',
+  lgpConditionCompressor1AShortCycle => '1.3.6.1.4.1.476.1.42.3.2.1.9.1.1',
+  lgpConditionCompressor1BShortCycle => '1.3.6.1.4.1.476.1.42.3.2.1.9.1.2',
   lgpConditionCompressor2ShortCycle => '1.3.6.1.4.1.476.1.42.3.2.1.9.2',
+  lgpConditionCompressor2AShortCycle => '1.3.6.1.4.1.476.1.42.3.2.1.9.2.1',
+  lgpConditionCompressor2BShortCycle => '1.3.6.1.4.1.476.1.42.3.2.1.9.2.2',
   lgpConditionCompressorLowSuctionPressure => '1.3.6.1.4.1.476.1.42.3.2.1.10',
+  lgpConditionCompressor1LowSuctionPressure => '1.3.6.1.4.1.476.1.42.3.2.1.10.1',
+  lgpConditionCompressor2LowSuctionPressure => '1.3.6.1.4.1.476.1.42.3.2.1.10.2',
   lgpConditionMainFanOverLoad => '1.3.6.1.4.1.476.1.42.3.2.1.11',
   lgpConditionManualOverride => '1.3.6.1.4.1.476.1.42.3.2.1.12',
   lgpConditionStandbyGlycoolPumpOn => '1.3.6.1.4.1.476.1.42.3.2.1.13',
@@ -53,7 +64,9 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'LIEBERT-GP-CONDITIONS
   lgpConditionStandbyUnitOn => '1.3.6.1.4.1.476.1.42.3.2.1.22',
   lgpConditionCompressorLowPressure => '1.3.6.1.4.1.476.1.42.3.2.1.23',
   lgpConditionCompressor1LowPressure => '1.3.6.1.4.1.476.1.42.3.2.1.23.1',
+  lgpConditionTandemCompressorCircuit1LowPressure => '1.3.6.1.4.1.476.1.42.3.2.1.23.1.1',
   lgpConditionCompressor2LowPressure => '1.3.6.1.4.1.476.1.42.3.2.1.23.2',
+  lgpConditionTandemCompressorCircuit2LowPressure => '1.3.6.1.4.1.476.1.42.3.2.1.23.2.1',
   lgpConditionCompressor3LowPressure => '1.3.6.1.4.1.476.1.42.3.2.1.23.3',
   lgpConditionCompressor4LowPressure => '1.3.6.1.4.1.476.1.42.3.2.1.23.4',
   lgpConditionHighWaterInPan => '1.3.6.1.4.1.476.1.42.3.2.1.24',
@@ -120,16 +133,32 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'LIEBERT-GP-CONDITIONS
   lgpConditionOutputToLoadOverLimit => '1.3.6.1.4.1.476.1.42.3.2.1.40.5',
   lgpConditionOutputToLoadOverload => '1.3.6.1.4.1.476.1.42.3.2.1.40.6',
   lgpConditionParallelSysOverload => '1.3.6.1.4.1.476.1.42.3.2.1.40.7',
+  lgpConditionBypassCurrentOverload => '1.3.6.1.4.1.476.1.42.3.2.1.40.8',
+  lgpConditionBypassCurrentOverloadPhsA => '1.3.6.1.4.1.476.1.42.3.2.1.40.8.1',
+  lgpConditionBypassCurrentOverloadPhsB => '1.3.6.1.4.1.476.1.42.3.2.1.40.8.2',
+  lgpConditionBypassCurrentOverloadPhsC => '1.3.6.1.4.1.476.1.42.3.2.1.40.8.3',
   lgpConditionScrShort => '1.3.6.1.4.1.476.1.42.3.2.1.41',
   lgpConditionSource1ScrShort => '1.3.6.1.4.1.476.1.42.3.2.1.41.1',
   lgpConditionSource2ScrShort => '1.3.6.1.4.1.476.1.42.3.2.1.41.2',
   lgpConditionBypassScrShort => '1.3.6.1.4.1.476.1.42.3.2.1.41.3',
+  lgpConditionInvStaticSwScrShort => '1.3.6.1.4.1.476.1.42.3.2.1.41.4',
+  lgpConditionSource1NeutralScrShort => '1.3.6.1.4.1.476.1.42.3.2.1.41.5',
+  lgpConditionSource2NeutralScrShort => '1.3.6.1.4.1.476.1.42.3.2.1.41.6',
   lgpConditionScrOpen => '1.3.6.1.4.1.476.1.42.3.2.1.42',
   lgpConditionSource1ScrOpen => '1.3.6.1.4.1.476.1.42.3.2.1.42.1',
   lgpConditionSource2ScrOpen => '1.3.6.1.4.1.476.1.42.3.2.1.42.2',
   lgpConditionBypassScrOpen => '1.3.6.1.4.1.476.1.42.3.2.1.42.3',
+  lgpConditionSource1NeutralScrOpen => '1.3.6.1.4.1.476.1.42.3.2.1.42.4',
+  lgpConditionSource2NeutralScrOpen => '1.3.6.1.4.1.476.1.42.3.2.1.42.5',
   lgpConditionFanFailure => '1.3.6.1.4.1.476.1.42.3.2.1.43',
   lgpConditionFan1Failure => '1.3.6.1.4.1.476.1.42.3.2.1.43.1',
+  lgpConditionRedundantFanFailure => '1.3.6.1.4.1.476.1.42.3.2.1.43.2',
+  lgpConditionMultipleFanFailure => '1.3.6.1.4.1.476.1.42.3.2.1.43.3',
+  lgpConditionBlowerFanFailure => '1.3.6.1.4.1.476.1.42.3.2.1.43.4',
+  lgpConditionBottomBlowerFanFailure => '1.3.6.1.4.1.476.1.42.3.2.1.43.4.1',
+  lgpConditionTopBlowerFanFailure => '1.3.6.1.4.1.476.1.42.3.2.1.43.4.2',
+  lgpConditionCondenserFanVFDFailure => '1.3.6.1.4.1.476.1.42.3.2.1.43.5',
+  lgpConditionFanPowerFailure => '1.3.6.1.4.1.476.1.42.3.2.1.43.6',
   lgpConditionTransferInhibited => '1.3.6.1.4.1.476.1.42.3.2.1.44',
   lgpConditionAutoReTransferPrimed => '1.3.6.1.4.1.476.1.42.3.2.1.45',
   lgpConditionSourcesOutOfSync => '1.3.6.1.4.1.476.1.42.3.2.1.46',
@@ -156,25 +185,45 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'LIEBERT-GP-CONDITIONS
   lgpConditionSource2BypassDisconnectClosed => '1.3.6.1.4.1.476.1.42.3.2.1.51.8',
   lgpConditionOutputToLoadNeutralDisconnectOpen => '1.3.6.1.4.1.476.1.42.3.2.1.51.9',
   lgpConditionBatteryDisconnectOpen => '1.3.6.1.4.1.476.1.42.3.2.1.51.10',
+  lgpConditionBatteryDiscOpenCab01 => '1.3.6.1.4.1.476.1.42.3.2.1.51.10.1',
+  lgpConditionBatteryDiscOpenCab02 => '1.3.6.1.4.1.476.1.42.3.2.1.51.10.2',
+  lgpConditionBatteryDiscOpenCab03 => '1.3.6.1.4.1.476.1.42.3.2.1.51.10.3',
+  lgpConditionBatteryDiscOpenCab04 => '1.3.6.1.4.1.476.1.42.3.2.1.51.10.4',
+  lgpConditionBatteryDiscOpenCab05 => '1.3.6.1.4.1.476.1.42.3.2.1.51.10.5',
+  lgpConditionBatteryDiscOpenCab06 => '1.3.6.1.4.1.476.1.42.3.2.1.51.10.6',
+  lgpConditionBatteryDiscOpenCab07 => '1.3.6.1.4.1.476.1.42.3.2.1.51.10.7',
+  lgpConditionBatteryDiscOpenCab08 => '1.3.6.1.4.1.476.1.42.3.2.1.51.10.8',
   lgpConditionInputDisconnectOpen => '1.3.6.1.4.1.476.1.42.3.2.1.51.11',
   lgpConditionOutputToLoadDisconnectOpen => '1.3.6.1.4.1.476.1.42.3.2.1.51.12',
   lgpConditionBypassDisconnectOpen => '1.3.6.1.4.1.476.1.42.3.2.1.51.13',
   lgpConditionStaticSwitchDisconnectOpen => '1.3.6.1.4.1.476.1.42.3.2.1.51.14',
+  lgpConditionBreakerOpenFailure => '1.3.6.1.4.1.476.1.42.3.2.1.51.15',
+  lgpConditionBreakerCloseFailure => '1.3.6.1.4.1.476.1.42.3.2.1.51.16',
   lgpConditionFrequencyDeviation => '1.3.6.1.4.1.476.1.42.3.2.1.52',
   lgpConditionSource1FrequencyDeviation => '1.3.6.1.4.1.476.1.42.3.2.1.52.1',
   lgpConditionSource2FrequencyDeviation => '1.3.6.1.4.1.476.1.42.3.2.1.52.2',
   lgpConditionInputFrequencyDeviation => '1.3.6.1.4.1.476.1.42.3.2.1.52.3',
   lgpConditionOutputToLoadFrequencyDeviation => '1.3.6.1.4.1.476.1.42.3.2.1.52.4',
+  lgpConditionBypassFrequencyDeviation => '1.3.6.1.4.1.476.1.42.3.2.1.52.5',
   lgpConditionOverCurrent => '1.3.6.1.4.1.476.1.42.3.2.1.53',
   lgpConditionSource1OverCurrent => '1.3.6.1.4.1.476.1.42.3.2.1.53.1',
   lgpConditionSource2OverCurrent => '1.3.6.1.4.1.476.1.42.3.2.1.53.2',
   lgpConditionOutputToLoadOverCurrent => '1.3.6.1.4.1.476.1.42.3.2.1.53.3',
+  lgpConditionOutputToLoadOverCurrentPhsA => '1.3.6.1.4.1.476.1.42.3.2.1.53.3.1',
+  lgpConditionOutputToLoadOverCurrentPhsB => '1.3.6.1.4.1.476.1.42.3.2.1.53.3.2',
+  lgpConditionOutputToLoadOverCurrentPhsC => '1.3.6.1.4.1.476.1.42.3.2.1.53.3.3',
   lgpConditionGroundOverCurrent => '1.3.6.1.4.1.476.1.42.3.2.1.53.4',
   lgpConditionRectifierOverCurrent => '1.3.6.1.4.1.476.1.42.3.2.1.53.5',
   lgpConditionInverterOverCurrent => '1.3.6.1.4.1.476.1.42.3.2.1.53.6',
+  lgpConditionInverterOverCurrentPhsA => '1.3.6.1.4.1.476.1.42.3.2.1.53.6.1',
+  lgpConditionInverterOverCurrentPhsB => '1.3.6.1.4.1.476.1.42.3.2.1.53.6.2',
+  lgpConditionInverterOverCurrentPhsC => '1.3.6.1.4.1.476.1.42.3.2.1.53.6.3',
   lgpConditionBatteryConverterOverCurrent => '1.3.6.1.4.1.476.1.42.3.2.1.53.7',
   lgpConditionBatteryBalancerOverCurrent => '1.3.6.1.4.1.476.1.42.3.2.1.53.8',
   lgpConditionHumidifierOverCurrent => '1.3.6.1.4.1.476.1.42.3.2.1.53.9',
+  lgpConditionInputOverCurrent => '1.3.6.1.4.1.476.1.42.3.2.1.53.10',
+  lgpConditionSource1NeutralOverCurrent => '1.3.6.1.4.1.476.1.42.3.2.1.53.11',
+  lgpConditionSource2NeutralOverCurrent => '1.3.6.1.4.1.476.1.42.3.2.1.53.12',
   lgpConditionSensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54',
   lgpConditionOutputToLoadVoltageSensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.1',
   lgpConditionSource1VoltageSensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.2',
@@ -192,6 +241,18 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'LIEBERT-GP-CONDITIONS
   lgpConditionCabinetTemperatureSensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.14',
   lgpConditionCabinetHumiditySensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.15',
   lgpConditionRoomTempSensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.16',
+  lgpConditionBatteryTempSensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.17',
+  lgpConditionAirSensorAFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.18',
+  lgpConditionAirSensorBFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.19',
+  lgpConditionChilledWaterSupplySensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.20',
+  lgpConditionRefrigerantSupplySensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.21',
+  lgpConditionFluidSupplySensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.22',
+  lgpConditionCompressorLowPressureSensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.23',
+  lgpConditionCompressor1LowPressureSensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.23.1',
+  lgpConditionRemoteSensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.24',
+  lgpConditionAirSupplyTempSensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.25',
+  lgpConditionAirReturnTempSensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.26',
+  lgpConditionCompressorHighPressureSensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.54.27',
   lgpConditionInternalCommunicationFailure => '1.3.6.1.4.1.476.1.42.3.2.1.55',
   lgpConditionExternalCommunicationFailure => '1.3.6.1.4.1.476.1.42.3.2.1.56',
   lgpConditionSourceGateDriveFailure => '1.3.6.1.4.1.476.1.42.3.2.1.57',
@@ -203,6 +264,7 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'LIEBERT-GP-CONDITIONS
   lgpConditionSource2DisconnectShuntTripFailure => '1.3.6.1.4.1.476.1.42.3.2.1.58.3',
   lgpConditionInverterDisconnectFailure => '1.3.6.1.4.1.476.1.42.3.2.1.58.4',
   lgpConditionBatteryDisconnectFailure => '1.3.6.1.4.1.476.1.42.3.2.1.58.5',
+  lgpConditionRectifierDisconnectFailure => '1.3.6.1.4.1.476.1.42.3.2.1.58.6',
   lgpConditionOverTemperature => '1.3.6.1.4.1.476.1.42.3.2.1.59',
   lgpConditionHeatSink1OverTemperature => '1.3.6.1.4.1.476.1.42.3.2.1.59.1',
   lgpConditionAmbient1OverTemperature => '1.3.6.1.4.1.476.1.42.3.2.1.59.2',
@@ -217,6 +279,9 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'LIEBERT-GP-CONDITIONS
   lgpConditionBatteryBalancerInductorOverTemperature => '1.3.6.1.4.1.476.1.42.3.2.1.59.11',
   lgpConditionChilledWaterOverTemperature => '1.3.6.1.4.1.476.1.42.3.2.1.59.12',
   lgpConditionElectricHeatersOverTemperature => '1.3.6.1.4.1.476.1.42.3.2.1.59.13',
+  lgpConditionInletAirOverTemperature => '1.3.6.1.4.1.476.1.42.3.2.1.59.14',
+  lgpConditionSystemOverTempWarning => '1.3.6.1.4.1.476.1.42.3.2.1.59.15',
+  lgpConditionHighTemperatureBattString => '1.3.6.1.4.1.476.1.42.3.2.1.59.16',
   lgpConditionLoadOnAlternateSource => '1.3.6.1.4.1.476.1.42.3.2.1.60',
   lgpConditionPhaseRotationError => '1.3.6.1.4.1.476.1.42.3.2.1.61',
   lgpConditionSource1PhaseRotationError => '1.3.6.1.4.1.476.1.42.3.2.1.61.1',
@@ -250,6 +315,8 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'LIEBERT-GP-CONDITIONS
   lgpConditonEmergencyPowerOff => '1.3.6.1.4.1.476.1.42.3.2.1.86',
   lgpConditionInverterBackFeed => '1.3.6.1.4.1.476.1.42.3.2.1.87',
   lgpConditionDcGroundFault => '1.3.6.1.4.1.476.1.42.3.2.1.88',
+  lgpConditionDcGroundFaultPos => '1.3.6.1.4.1.476.1.42.3.2.1.88.1',
+  lgpConditionDcGroundFaultNeg => '1.3.6.1.4.1.476.1.42.3.2.1.88.2',
   lgpConditionStaticTransferSwitchInhibited => '1.3.6.1.4.1.476.1.42.3.2.1.89',
   lgpConditionBatteryLogFullWarning => '1.3.6.1.4.1.476.1.42.3.2.1.90',
   lgpConditionInputCurrentUnbalanced => '1.3.6.1.4.1.476.1.42.3.2.1.91',
@@ -269,6 +336,9 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'LIEBERT-GP-CONDITIONS
   lgpConditionMainControlFailure => '1.3.6.1.4.1.476.1.42.3.2.1.96.1',
   lgpConditionRedundantControlFailure => '1.3.6.1.4.1.476.1.42.3.2.1.96.2',
   lgpConditionParallelSysControlFailure => '1.3.6.1.4.1.476.1.42.3.2.1.96.3',
+  lgpConditionMainControlCommFailure => '1.3.6.1.4.1.476.1.42.3.2.1.96.4',
+  lgpConditionControlBoardFailure => '1.3.6.1.4.1.476.1.42.3.2.1.96.5',
+  lgpConditionHumidifierControlBdFailure => '1.3.6.1.4.1.476.1.42.3.2.1.96.5.1',
   lgpConditionControlWarning => '1.3.6.1.4.1.476.1.42.3.2.1.97',
   lgpConditionMainControlWarning => '1.3.6.1.4.1.476.1.42.3.2.1.97.1',
   lgpConditionRedundantControlWarning => '1.3.6.1.4.1.476.1.42.3.2.1.97.2',
@@ -322,6 +392,7 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'LIEBERT-GP-CONDITIONS
   lgpConditionHotGasRunHrsExceeded => '1.3.6.1.4.1.476.1.42.3.2.1.134.9',
   lgpConditionHumidifierRunHrsExceeded => '1.3.6.1.4.1.476.1.42.3.2.1.134.10',
   lgpConditionDehumidiferRunHrsExceeded => '1.3.6.1.4.1.476.1.42.3.2.1.134.11',
+  lgpConditionFanRunHrsExceeded => '1.3.6.1.4.1.476.1.42.3.2.1.134.12',
   lgpConditionCommWarning => '1.3.6.1.4.1.476.1.42.3.2.1.135',
   lgpConditionCommWarningUnit1 => '1.3.6.1.4.1.476.1.42.3.2.1.135.1',
   lgpConditionCommWarningUnit2 => '1.3.6.1.4.1.476.1.42.3.2.1.135.2',
@@ -351,13 +422,26 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'LIEBERT-GP-CONDITIONS
   lgpConditionHighTemperatureDigitalScroll2 => '1.3.6.1.4.1.476.1.42.3.2.1.142.3',
   lgpConditionHighTemperatureUser1 => '1.3.6.1.4.1.476.1.42.3.2.1.142.4',
   lgpConditionHighTemperatureInternal => '1.3.6.1.4.1.476.1.42.3.2.1.142.5',
+  lgpConditionHighTemperatureExternalAirSensorA => '1.3.6.1.4.1.476.1.42.3.2.1.142.6',
+  lgpConditionHighTemperatureExternalAirSensorB => '1.3.6.1.4.1.476.1.42.3.2.1.142.7',
+  lgpConditionHighTemperatureRefrigerantSupply => '1.3.6.1.4.1.476.1.42.3.2.1.142.8',
+  lgpConditionHighTemperatureFluidSupply => '1.3.6.1.4.1.476.1.42.3.2.1.142.9',
+  lgpConditionHighTemperatureSupplyAir => '1.3.6.1.4.1.476.1.42.3.2.1.142.10',
+  lgpConditionHighTemperatureReturnAir => '1.3.6.1.4.1.476.1.42.3.2.1.142.11',
   lgpConditionLowTemperatureGroup => '1.3.6.1.4.1.476.1.42.3.2.1.143',
   lgpConditionLowTemperatureSensor1 => '1.3.6.1.4.1.476.1.42.3.2.1.143.1',
   lgpConditionLowTemperatureInternal => '1.3.6.1.4.1.476.1.42.3.2.1.143.2',
+  lgpConditionLowTemperatureExternalAirSensorA => '1.3.6.1.4.1.476.1.42.3.2.1.143.3',
+  lgpConditionLowTemperatureExternalAirSensorB => '1.3.6.1.4.1.476.1.42.3.2.1.143.4',
+  lgpConditionLowTemperatureRefrigerantSupply => '1.3.6.1.4.1.476.1.42.3.2.1.143.5',
+  lgpConditionLowTemperatureFluidSupply => '1.3.6.1.4.1.476.1.42.3.2.1.143.6',
+  lgpConditionLowTemperatureSupplyAir => '1.3.6.1.4.1.476.1.42.3.2.1.143.7',
   lgpConditionHighHumidityGroup => '1.3.6.1.4.1.476.1.42.3.2.1.144',
   lgpConditionHighHumiditySensor1 => '1.3.6.1.4.1.476.1.42.3.2.1.144.1',
+  lgpConditionHighHumidityReturnAir => '1.3.6.1.4.1.476.1.42.3.2.1.144.2',
   lgpConditionLowHumidityGroup => '1.3.6.1.4.1.476.1.42.3.2.1.145',
   lgpConditionLowHumiditySensor1 => '1.3.6.1.4.1.476.1.42.3.2.1.145.1',
+  lgpConditionLowHumidityReturnAir => '1.3.6.1.4.1.476.1.42.3.2.1.145.2',
   lgpConditionPeerNetworkNoMaster => '1.3.6.1.4.1.476.1.42.3.2.1.146',
   lgpConditionNoOnOffPermissions => '1.3.6.1.4.1.476.1.42.3.2.1.147',
   lgpConditionPeerNetworkFailure => '1.3.6.1.4.1.476.1.42.3.2.1.148',
@@ -412,37 +496,217 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'LIEBERT-GP-CONDITIONS
   lgpConditionCondenserFailureGroup => '1.3.6.1.4.1.476.1.42.3.2.1.180',
   lgpConditionCondenser1Failure => '1.3.6.1.4.1.476.1.42.3.2.1.180.1',
   lgpConditionCondenser2Failure => '1.3.6.1.4.1.476.1.42.3.2.1.180.2',
+  lgpConditionCondenserTVSSFailure => '1.3.6.1.4.1.476.1.42.3.2.1.180.3',
   lgpConditionHumidifierCyclinderWorn => '1.3.6.1.4.1.476.1.42.3.2.1.181',
   lgpConditionUnderCurrent => '1.3.6.1.4.1.476.1.42.3.2.1.182',
   lgpConditionHumidifierUnderCurrent => '1.3.6.1.4.1.476.1.42.3.2.1.182.1',
+  lgpConditionInputUnderCurrent => '1.3.6.1.4.1.476.1.42.3.2.1.182.2',
   lgpConditionHeatRejectorGroup => '1.3.6.1.4.1.476.1.42.3.2.1.183',
   lgpConditionHeatRejectorFanFailure => '1.3.6.1.4.1.476.1.42.3.2.1.183.1',
   lgpConditionHeatRejectorVoltageSuppressionFailure => '1.3.6.1.4.1.476.1.42.3.2.1.183.2',
   lgpConditionFreeCoolLockout => '1.3.6.1.4.1.476.1.42.3.2.1.184',
   lgpConditionWaterLeakSensorFailure => '1.3.6.1.4.1.476.1.42.3.2.1.185',
   lgpConditionNoLoadDetectedWarning => '1.3.6.1.4.1.476.1.42.3.2.1.186',
+  lgpConditionFirmwareGroup => '1.3.6.1.4.1.476.1.42.3.2.1.187',
+  lgpConditionFirmwareUpdateRequired => '1.3.6.1.4.1.476.1.42.3.2.1.187.3',
+  lgpConditionTestGroup => '1.3.6.1.4.1.476.1.42.3.2.1.188',
+  lgpConditionTest01 => '1.3.6.1.4.1.476.1.42.3.2.1.188.5',
+  lgpConditionReceptacleBranchGroup => '1.3.6.1.4.1.476.1.42.3.2.1.190',
+  lgpConditionRcpBranchFailure => '1.3.6.1.4.1.476.1.42.3.2.1.190.5',
+  lgpConditionRcpBranchBreakerOpen => '1.3.6.1.4.1.476.1.42.3.2.1.190.10',
+  lgpConditionInputUnqualified => '1.3.6.1.4.1.476.1.42.3.2.1.192',
+  lgpConditionBypassUnavailable => '1.3.6.1.4.1.476.1.42.3.2.1.193',
+  lgpConditionAutoTransferFailed => '1.3.6.1.4.1.476.1.42.3.2.1.194',
+  lgpConditionSBSUnavailable => '1.3.6.1.4.1.476.1.42.3.2.1.195',
+  lgpConditionSBSOverload => '1.3.6.1.4.1.476.1.42.3.2.1.196',
+  lgpConditionExcessPulseParallel => '1.3.6.1.4.1.476.1.42.3.2.1.197',
+  lgpConditionRemoteBypassSwitchOffExt => '1.3.6.1.4.1.476.1.42.3.2.1.198',
+  lgpConditionManTransferInhibited => '1.3.6.1.4.1.476.1.42.3.2.1.199',
+  lgpConditionManReTransferInhibited => '1.3.6.1.4.1.476.1.42.3.2.1.200',
+  lgpConditionBatteryChargeError => '1.3.6.1.4.1.476.1.42.3.2.1.201',
+  lgpConditionBatteryAutoTestInhibited => '1.3.6.1.4.1.476.1.42.3.2.1.202',
+  lgpConditionBatteryChargeReducedExt => '1.3.6.1.4.1.476.1.42.3.2.1.203',
+  lgpConditionBatteryCapacityLow => '1.3.6.1.4.1.476.1.42.3.2.1.204',
+  lgpConditionBatteryTempImbalance => '1.3.6.1.4.1.476.1.42.3.2.1.205',
+  lgpConditionBatteryEqualize => '1.3.6.1.4.1.476.1.42.3.2.1.206',
+  lgpConditionBatteryChargeInhibitedExt => '1.3.6.1.4.1.476.1.42.3.2.1.207',
+  lgpConditionServiceExtBatteryMonitorGroup => '1.3.6.1.4.1.476.1.42.3.2.1.208',
+  lgpConditionServiceExtBatteryMonitor1 => '1.3.6.1.4.1.476.1.42.3.2.1.208.1',
+  lgpConditionServiceExtBatteryMonitor2 => '1.3.6.1.4.1.476.1.42.3.2.1.208.2',
+  lgpConditionBatteryGroundFault => '1.3.6.1.4.1.476.1.42.3.2.1.209',
+  lgpConditionBatteryLowShutdown => '1.3.6.1.4.1.476.1.42.3.2.1.210',
+  lgpConditionEmergencyPowerOffLocal => '1.3.6.1.4.1.476.1.42.3.2.1.211',
+  lgpConditionOutputLowPFLagging => '1.3.6.1.4.1.476.1.42.3.2.1.212',
+  lgpConditionOutputLowPFLeading => '1.3.6.1.4.1.476.1.42.3.2.1.213',
+  lgpConditionOutputToLoadFault => '1.3.6.1.4.1.476.1.42.3.2.1.214',
+  lgpConditionInvRestartInhibitedExt => '1.3.6.1.4.1.476.1.42.3.2.1.215',
+  lgpConditionInverterShutdownOverload => '1.3.6.1.4.1.476.1.42.3.2.1.216',
+  lgpConditionInverterOffExt => '1.3.6.1.4.1.476.1.42.3.2.1.217',
+  lgpConditionInputContactGroup => '1.3.6.1.4.1.476.1.42.3.2.1.218',
+  lgpConditionInputContact01 => '1.3.6.1.4.1.476.1.42.3.2.1.218.1',
+  lgpConditionInputContact02 => '1.3.6.1.4.1.476.1.42.3.2.1.218.2',
+  lgpConditionInputContact03 => '1.3.6.1.4.1.476.1.42.3.2.1.218.3',
+  lgpConditionInputContact04 => '1.3.6.1.4.1.476.1.42.3.2.1.218.4',
+  lgpConditionInputContact05 => '1.3.6.1.4.1.476.1.42.3.2.1.218.5',
+  lgpConditionInputContact06 => '1.3.6.1.4.1.476.1.42.3.2.1.218.6',
+  lgpConditionInputContact07 => '1.3.6.1.4.1.476.1.42.3.2.1.218.7',
+  lgpConditionInputContact08 => '1.3.6.1.4.1.476.1.42.3.2.1.218.8',
+  lgpConditionInputContact09 => '1.3.6.1.4.1.476.1.42.3.2.1.218.9',
+  lgpConditionInputContact10 => '1.3.6.1.4.1.476.1.42.3.2.1.218.10',
+  lgpConditionInputContact11 => '1.3.6.1.4.1.476.1.42.3.2.1.218.11',
+  lgpConditionInputContact12 => '1.3.6.1.4.1.476.1.42.3.2.1.218.12',
+  lgpConditionInputContact13 => '1.3.6.1.4.1.476.1.42.3.2.1.218.13',
+  lgpConditionInputContact14 => '1.3.6.1.4.1.476.1.42.3.2.1.218.14',
+  lgpConditionInputContact15 => '1.3.6.1.4.1.476.1.42.3.2.1.218.15',
+  lgpConditionInputContact16 => '1.3.6.1.4.1.476.1.42.3.2.1.218.16',
+  lgpConditionRectifierOperInhibited => '1.3.6.1.4.1.476.1.42.3.2.1.219',
+  lgpConditionBypassBackFeedBrkrOpen => '1.3.6.1.4.1.476.1.42.3.2.1.220',
+  lgpConditionAutoRestartInProgress => '1.3.6.1.4.1.476.1.42.3.2.1.221',
+  lgpConditionAutoRestartInhibitedExt => '1.3.6.1.4.1.476.1.42.3.2.1.222',
+  lgpConditionAutoRestartFailed => '1.3.6.1.4.1.476.1.42.3.2.1.223',
+  lgpConditionInputOnGenerator => '1.3.6.1.4.1.476.1.42.3.2.1.224',
+  lgpConditionInputFilterCycleLock => '1.3.6.1.4.1.476.1.42.3.2.1.225',
+  lgpConditionServiceCodeActive => '1.3.6.1.4.1.476.1.42.3.2.1.226',
+  lgpConditionLoadBusSyncActive => '1.3.6.1.4.1.476.1.42.3.2.1.227',
+  lgpConditionLoadBusSyncInhibited => '1.3.6.1.4.1.476.1.42.3.2.1.228',
+  lgpConditionControlsResetRequired => '1.3.6.1.4.1.476.1.42.3.2.1.229',
+  lgpConditionEquipTempSensorFailed => '1.3.6.1.4.1.476.1.42.3.2.1.230',
+  lgpConditionInputCurrentImbalance => '1.3.6.1.4.1.476.1.42.3.2.1.231',
+  lgpConditionPumpGroup => '1.3.6.1.4.1.476.1.42.3.2.1.232',
+  lgpConditionPumpFlowLoss => '1.3.6.1.4.1.476.1.42.3.2.1.232.1',
+  lgpConditionPump1FlowLoss => '1.3.6.1.4.1.476.1.42.3.2.1.232.1.1',
+  lgpConditionPump2FlowLoss => '1.3.6.1.4.1.476.1.42.3.2.1.232.1.2',
+  lgpConditionPumpShortCycle => '1.3.6.1.4.1.476.1.42.3.2.1.232.2',
+  lgpConditionPumpInverterShortCycle => '1.3.6.1.4.1.476.1.42.3.2.1.232.3',
+  lgpConditionPump1InverterShortCycle => '1.3.6.1.4.1.476.1.42.3.2.1.232.3.1',
+  lgpConditionPump2InverterShortCycle => '1.3.6.1.4.1.476.1.42.3.2.1.232.3.2',
+  lgpConditionValveGroup => '1.3.6.1.4.1.476.1.42.3.2.1.233',
+  lgpConditionChilledWaterValvePosition => '1.3.6.1.4.1.476.1.42.3.2.1.233.1',
+  lgpConditionCondensationDetected => '1.3.6.1.4.1.476.1.42.3.2.1.234',
+  lgpConditionMaintenanceGroup => '1.3.6.1.4.1.476.1.42.3.2.1.235',
+  lgpConditionMaintenanceDue => '1.3.6.1.4.1.476.1.42.3.2.1.235.1',
+  lgpConditionMaintenanceComplete => '1.3.6.1.4.1.476.1.42.3.2.1.235.2',
+  lgpConditionExternalEventSignalGroup => '1.3.6.1.4.1.476.1.42.3.2.1.236',
+  lgpConditionExternalFireDetect => '1.3.6.1.4.1.476.1.42.3.2.1.236.1',
+  lgpConditionExternalFlowLoss => '1.3.6.1.4.1.476.1.42.3.2.1.236.2',
+  lgpConditionExternalReheatLockout => '1.3.6.1.4.1.476.1.42.3.2.1.236.3',
+  lgpConditionExternalOverTemp => '1.3.6.1.4.1.476.1.42.3.2.1.236.4',
+  lgpConditionExternalCompLockout => '1.3.6.1.4.1.476.1.42.3.2.1.236.5',
+  lgpConditionExternalHumidifierLockout => '1.3.6.1.4.1.476.1.42.3.2.1.236.6',
+  lgpConditionComponentShutdownGroup => '1.3.6.1.4.1.476.1.42.3.2.1.237',
+  lgpConditionComponentShutdownPartial => '1.3.6.1.4.1.476.1.42.3.2.1.237.1',
+  lgpConditionComponentShutdownHighPower => '1.3.6.1.4.1.476.1.42.3.2.1.237.2',
+  lgpConditionCondenserProblemGroup => '1.3.6.1.4.1.476.1.42.3.2.1.238',
+  lgpConditionCondenser1Problem => '1.3.6.1.4.1.476.1.42.3.2.1.238.1',
+  lgpConditionHumidityOutOfPropBand => '1.3.6.1.4.1.476.1.42.3.2.1.239',
+  lgpConditionEnvRemoteSensorGroup => '1.3.6.1.4.1.476.1.42.3.2.1.240',
+  lgpConditionEnvRemoteSensor1Issue => '1.3.6.1.4.1.476.1.42.3.2.1.240.1',
+  lgpConditionEnvRemoteSensor2Issue => '1.3.6.1.4.1.476.1.42.3.2.1.240.2',
+  lgpConditionEnvRemoteSensor3Issue => '1.3.6.1.4.1.476.1.42.3.2.1.240.3',
+  lgpConditionEnvRemoteSensor4Issue => '1.3.6.1.4.1.476.1.42.3.2.1.240.4',
+  lgpConditionEnvRemoteSensor5Issue => '1.3.6.1.4.1.476.1.42.3.2.1.240.5',
+  lgpConditionEnvRemoteSensor6Issue => '1.3.6.1.4.1.476.1.42.3.2.1.240.6',
+  lgpConditionEnvRemoteSensor7Issue => '1.3.6.1.4.1.476.1.42.3.2.1.240.7',
+  lgpConditionEnvRemoteSensor8Issue => '1.3.6.1.4.1.476.1.42.3.2.1.240.8',
+  lgpConditionEnvRemoteSensor9Issue => '1.3.6.1.4.1.476.1.42.3.2.1.240.9',
+  lgpConditionEnvRemoteSensor10Issue => '1.3.6.1.4.1.476.1.42.3.2.1.240.10',
+  lgpConditionNeutralSnubberBoardCommFailure => '1.3.6.1.4.1.476.1.42.3.2.1.241',
+  lgpConditionRedundantChargerFailure => '1.3.6.1.4.1.476.1.42.3.2.1.242',
+  lgpConditionBoardInputContactorPowerFailure => '1.3.6.1.4.1.476.1.42.3.2.1.243',
+  lgpConditionBoard1InputContactorPowerFailure => '1.3.6.1.4.1.476.1.42.3.2.1.243.1',
+  lgpConditionBoard2InputContactorPowerFailure => '1.3.6.1.4.1.476.1.42.3.2.1.243.2',
+  lgpConditionTooManySensors => '1.3.6.1.4.1.476.1.42.3.2.1.5423',
+  lgpConditionDoorSwitchOpen => '1.3.6.1.4.1.476.1.42.3.2.1.5471',
+  lgpConditionContactClosureOpen => '1.3.6.1.4.1.476.1.42.3.2.1.5479',
+  lgpConditionContactClosureClosed => '1.3.6.1.4.1.476.1.42.3.2.1.5480',
   lgpConditionsPresent => '1.3.6.1.4.1.476.1.42.3.2.2',
   lgpConditionsTable => '1.3.6.1.4.1.476.1.42.3.2.3',
+  lgpConditionsEntry => '1.3.6.1.4.1.476.1.42.3.2.3.1', # dummy /Table/Entry/
   lgpConditionEntry => '1.3.6.1.4.1.476.1.42.3.2.3.1',
   lgpConditionId => '1.3.6.1.4.1.476.1.42.3.2.3.1.1',
   lgpConditionDescr => '1.3.6.1.4.1.476.1.42.3.2.3.1.2',
   lgpConditionTime => '1.3.6.1.4.1.476.1.42.3.2.3.1.3',
+  lgpConditionTableRef => '1.3.6.1.4.1.476.1.42.3.2.3.1.5',
+  lgpConditionTableRowRef => '1.3.6.1.4.1.476.1.42.3.2.3.1.6',
+  lgpConditionType => '1.3.6.1.4.1.476.1.42.3.2.3.1.10',
+  lgpConditionTypeDefinition => 'LIEBERT-GP-CONDITIONS-MIB::lgpConditionType',
+  lgpConditionCurrentState => '1.3.6.1.4.1.476.1.42.3.2.3.1.12',
+  lgpConditionCurrentStateDefinition => 'LIEBERT-GP-CONDITIONS-MIB::lgpConditionCurrentState',
+  lgpConditionSeverity => '1.3.6.1.4.1.476.1.42.3.2.3.1.14',
+  lgpConditionSeverityDefinition => 'LIEBERT-GP-CONDITIONS-MIB::lgpConditionSeverity',
+  lgpConditionAcknowledged => '1.3.6.1.4.1.476.1.42.3.2.3.1.18',
+  lgpConditionAcknowledgedDefinition => 'LIEBERT-GP-CONDITIONS-MIB::lgpConditionAcknowledged',
+  lgpConditionAckReq => '1.3.6.1.4.1.476.1.42.3.2.3.1.19',
+  lgpConditionAckReqDefinition => 'LIEBERT-GP-CONDITIONS-MIB::lgpConditionAckReq',
   lgpConditionControl => '1.3.6.1.4.1.476.1.42.3.2.4',
   lgpConditionControlEventReset => '1.3.6.1.4.1.476.1.42.3.2.4.1',
   lgpConditionControlEventResetDefinition => 'LIEBERT-GP-CONDITIONS-MIB::lgpConditionControlEventReset',
   lgpConditionControlEventAck => '1.3.6.1.4.1.476.1.42.3.2.4.2',
   lgpConditionControlEventAckDefinition => 'LIEBERT-GP-CONDITIONS-MIB::lgpConditionControlEventAck',
+  lgpConditionControlTable => '1.3.6.1.4.1.476.1.42.3.2.4.20',
+  lgpConditionControlEntry => '1.3.6.1.4.1.476.1.42.3.2.4.20.1',
+  lgpConditionControlIndex => '1.3.6.1.4.1.476.1.42.3.2.4.20.1.1',
+  lgpConditionControlDescr => '1.3.6.1.4.1.476.1.42.3.2.4.20.1.2',
+  lgpConditionControlEnableStatus => '1.3.6.1.4.1.476.1.42.3.2.4.20.1.3',
+  lgpConditionControlEnableStatusDefinition => 'LIEBERT-GP-CONDITIONS-MIB::lgpConditionControlEnableStatus',
+  lgpConditionControlType => '1.3.6.1.4.1.476.1.42.3.2.4.20.1.4',
+  lgpConditionControlTypeDefinition => 'LIEBERT-GP-CONDITIONS-MIB::lgpConditionControlType',
+  lgpConditionControlEnableCapability => '1.3.6.1.4.1.476.1.42.3.2.4.20.1.5',
+  lgpConditionControlEnableCapabilityDefinition => 'LIEBERT-GP-CONDITIONS-MIB::lgpConditionControlEnableCapability',
   lgpConditionDescription => '1.3.6.1.4.1.476.1.42.3.2.5',
   lgpNetworkName => '1.3.6.1.4.1.476.1.42.3.2.6',
+  lgpFlexConditions => '1.3.6.1.4.1.476.1.42.3.2.7',
 };
 
 $Monitoring::GLPlugin::SNMP::MibsAndOids::definitions->{'LIEBERT-GP-CONDITIONS-MIB'} = {
-  lgpConditionControlEventReset => {
-    '1' => 'noAction',
-    '2' => 'resetAll',
+  lgpConditionCurrentState => {
+    '1' => 'active',
+    '2' => 'inactive',
+  },
+  lgpConditionType => {
+    '0' => 'not-specified',
+    '2' => 'message',
+    '4' => 'warning',
+    '6' => 'alarm',
+    '8' => 'fault',
   },
   lgpConditionControlEventAck => {
     '1' => 'noAction',
     '2' => 'ackAll',
   },
+  lgpConditionAcknowledged => {
+    '1' => 'notAcknowledged',
+    '2' => 'acknowledged',
+  },
+  lgpConditionSeverity => {
+    '0' => 'not-applicable',
+    '3' => 'minor',
+    '6' => 'major',
+    '9' => 'critical',
+  },
+  lgpConditionControlEventReset => {
+    '1' => 'noAction',
+    '2' => 'resetAll',
+  },
+  lgpConditionControlEnableCapability => {
+    '0' => 'not-specified',
+    '1' => 'read-only',
+    '2' => 'read-write',
+  },
+  lgpConditionAckReq => {
+    '1' => 'required',
+    '2' => 'notRequired',
+  },
+  lgpConditionControlType => {
+    '0' => 'not-specified',
+    '2' => 'message',
+    '4' => 'warning',
+    '6' => 'alarm',
+    '8' => 'fault',
+  },
+  lgpConditionControlEnableStatus => {
+    '0' => 'not-specified',
+    '1' => 'enabled',
+    '2' => 'disabled',
+  },
 };
