@@ -5,7 +5,8 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::origin->{'LIEBERT-GP-POWER-MIB'} = {
   name => 'LIEBERT-GP-POWER-MIB',
 };
 
-#$Monitoring::GLPlugin::SNMP::MibsAndOids::mib_ids->{'LIEBERT-GP-POWER-MIB'} = 
+$Monitoring::GLPlugin::SNMP::MibsAndOids::mib_ids->{'LIEBERT-GP-POWER-MIB'} =
+  '1.3.6.1.4.1.476.1.42.3.5';
 
 $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'LIEBERT-GP-POWER-MIB'} = {
   liebertGlobalProductsPowerModule => '1.3.6.1.4.1.476.1.42.1.6.1',
@@ -39,6 +40,17 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'LIEBERT-GP-POWER-MIB'
   lgpPwrBatteryCabinetType => '1.3.6.1.4.1.476.1.42.3.5.1.20.2',
   lgpPwrBatteryCabinetTypeDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrBatteryCabinetType',
   lgpPwrBatteryCabinetRatedCapacity => '1.3.6.1.4.1.476.1.42.3.5.1.20.3',
+  lgpPwrBatteryLeadAcidCellCount => '1.3.6.1.4.1.476.1.42.3.5.1.20.4',
+  lgpPwrBatteryNiCadCellCount => '1.3.6.1.4.1.476.1.42.3.5.1.20.5',
+  lgpPwrBatteryAmpHoursConsumed => '1.3.6.1.4.1.476.1.42.3.5.1.21',
+  lgpPwrBatteryAmpHoursDischargeConsumed => '1.3.6.1.4.1.476.1.42.3.5.1.22',
+  lgpPwrBatteryLastDischargeTime => '1.3.6.1.4.1.476.1.42.3.5.1.23',
+  lgpPwrBatteryLastCommissionTime => '1.3.6.1.4.1.476.1.42.3.5.1.24',
+  lgpPwrBatteryPresentDischargeTime => '1.3.6.1.4.1.476.1.42.3.5.1.25',
+  lgpPwrBatteryCapacityStatus => '1.3.6.1.4.1.476.1.42.3.5.1.26',
+  lgpPwrBatteryCapacityStatusDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrBatteryCapacityStatus',
+  lgpPwrBatteryCircuitBreakerState => '1.3.6.1.4.1.476.1.42.3.5.1.27',
+  lgpPwrBatteryCircuitBreakerStateDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrBatteryCircuitBreakerState',
   lgpPwrMeasurements => '1.3.6.1.4.1.476.1.42.3.5.2',
   lgpPwrWellKnownMeasurementPoints => '1.3.6.1.4.1.476.1.42.3.5.2.1',
   lgpPwrSource1Input => '1.3.6.1.4.1.476.1.42.3.5.2.1.1',
@@ -50,6 +62,7 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'LIEBERT-GP-POWER-MIB'
   lgpPwrMeasBypass => '1.3.6.1.4.1.476.1.42.3.5.2.1.7',
   lgpPwrMeasDcBus => '1.3.6.1.4.1.476.1.42.3.5.2.1.8',
   lgpPwrMeasSystemOutput => '1.3.6.1.4.1.476.1.42.3.5.2.1.9',
+  lgpPwrMeasBatteryCabinet => '1.3.6.1.4.1.476.1.42.3.5.2.1.10',
   lgpPwrMeasurementPointTable => '1.3.6.1.4.1.476.1.42.3.5.2.2',
   lgpPwrMeasurementPointEntry => '1.3.6.1.4.1.476.1.42.3.5.2.2.1',
   lgpPwrMeasurementPointIndex => '1.3.6.1.4.1.476.1.42.3.5.2.2.1.1',
@@ -68,6 +81,7 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'LIEBERT-GP-POWER-MIB'
   lgpPwrMeasurementPointNomCurrent => '1.3.6.1.4.1.476.1.42.3.5.2.2.1.14',
   lgpPwrMeasurementPointNomPowerFactor => '1.3.6.1.4.1.476.1.42.3.5.2.2.1.15',
   lgpPwrMeasurementPointNomVA => '1.3.6.1.4.1.476.1.42.3.5.2.2.1.16',
+  lgpPwrMeasurementPointNomW => '1.3.6.1.4.1.476.1.42.3.5.2.2.1.17',
   lgpPwrMeasurementPointPowerFactorTag => '1.3.6.1.4.1.476.1.42.3.5.2.2.1.19',
   lgpPwrMeasurementPointPowerFactorTagDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrMeasurementPointPowerFactorTag',
   lgpPwrLineMeasurementTable => '1.3.6.1.4.1.476.1.42.3.5.2.3',
@@ -93,6 +107,7 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'LIEBERT-GP-POWER-MIB'
   lgpPwrLineMeasurementVAR => '1.3.6.1.4.1.476.1.42.3.5.2.3.1.18',
   lgpPwrLineMeasurementPercentLoad => '1.3.6.1.4.1.476.1.42.3.5.2.3.1.19',
   lgpPwrLineMeasurementVolts => '1.3.6.1.4.1.476.1.42.3.5.2.3.1.20',
+  lgpPwrLineMeasurementVACapacity => '1.3.6.1.4.1.476.1.42.3.5.2.3.1.21',
   lgpPwrDcMeasurementPointTable => '1.3.6.1.4.1.476.1.42.3.5.2.4',
   lgpPwrDcMeasurementPointEntry => '1.3.6.1.4.1.476.1.42.3.5.2.4.1',
   lgpPwrDcMeasurementPointIndex => '1.3.6.1.4.1.476.1.42.3.5.2.4.1.1',
@@ -105,6 +120,7 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'LIEBERT-GP-POWER-MIB'
   lgpPwrWellKnownMeasurementTypes => '1.3.6.1.4.1.476.1.42.3.5.2.5',
   lgpPwrVoltsAc => '1.3.6.1.4.1.476.1.42.3.5.2.5.1',
   lgpPwrVoltsDc => '1.3.6.1.4.1.476.1.42.3.5.2.5.2',
+  lgpPwrAmpsNeutral => '1.3.6.1.4.1.476.1.42.3.5.2.5.3',
   lgpPwrStatus => '1.3.6.1.4.1.476.1.42.3.5.3',
   lgpPwrTransferCount => '1.3.6.1.4.1.476.1.42.3.5.3.1',
   lgpPwrAutoTransferTimer => '1.3.6.1.4.1.476.1.42.3.5.3.2',
@@ -157,6 +173,78 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'LIEBERT-GP-POWER-MIB'
   lgpPwrRotaryBreakerStatusDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrRotaryBreakerStatus',
   lgpPwrPowerFactorCorrection => '1.3.6.1.4.1.476.1.42.3.5.3.27',
   lgpPwrPowerFactorCorrectionDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrPowerFactorCorrection',
+  lgpPwrBypassSyncDiff => '1.3.6.1.4.1.476.1.42.3.5.3.28',
+  lgpPwrBypassOverloadShutdownTime => '1.3.6.1.4.1.476.1.42.3.5.3.29',
+  lgpPwrInverterOverloadShutdownTime => '1.3.6.1.4.1.476.1.42.3.5.3.30',
+  lgpPwrStateOutputSource => '1.3.6.1.4.1.476.1.42.3.5.3.31',
+  lgpPwrStateOutputSourceDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrStateOutputSource',
+  lgpPwrStateInputSource => '1.3.6.1.4.1.476.1.42.3.5.3.32',
+  lgpPwrStateInputSourceDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrStateInputSource',
+  lgpPwrStateInputQualification => '1.3.6.1.4.1.476.1.42.3.5.3.33',
+  lgpPwrStateInputQualificationDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrStateInputQualification',
+  lgpPwrStateBypassStaticSwitchState => '1.3.6.1.4.1.476.1.42.3.5.3.34',
+  lgpPwrStateBypassStaticSwitchStateDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrStateBypassStaticSwitchState',
+  lgpPwrStateBypassQualification => '1.3.6.1.4.1.476.1.42.3.5.3.35',
+  lgpPwrStateBypassQualificationDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrStateBypassQualification',
+  lgpPwrStateDCBusQualification => '1.3.6.1.4.1.476.1.42.3.5.3.36',
+  lgpPwrStateDCBusQualificationDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrStateDCBusQualification',
+  lgpPwrStateOutQualification => '1.3.6.1.4.1.476.1.42.3.5.3.37',
+  lgpPwrStateOutQualificationDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrStateOutQualification',
+  lgpPwrStateInverterQualification => '1.3.6.1.4.1.476.1.42.3.5.3.38',
+  lgpPwrStateInverterQualificationDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrStateInverterQualification',
+  lgpPwrStateInverterState => '1.3.6.1.4.1.476.1.42.3.5.3.39',
+  lgpPwrStateInverterStateDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrStateInverterState',
+  lgpPwrStateRectifierState => '1.3.6.1.4.1.476.1.42.3.5.3.40',
+  lgpPwrStateRectifierStateDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrStateRectifierState',
+  lgpPwrStateModuleGroup => '1.3.6.1.4.1.476.1.42.3.5.3.41',
+  lgpPwrStateUpsModuleCount => '1.3.6.1.4.1.476.1.42.3.5.3.41.1',
+  lgpPwrStateUpsModuleRedundantCount => '1.3.6.1.4.1.476.1.42.3.5.3.41.2',
+  lgpPwrStateBackfeedBrkrState => '1.3.6.1.4.1.476.1.42.3.5.3.42',
+  lgpPwrStateBackfeedBrkrStateDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrStateBackfeedBrkrState',
+  lgpPwrStateLoadDisconnectState => '1.3.6.1.4.1.476.1.42.3.5.3.43',
+  lgpPwrStateLoadDisconnectStateDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrStateLoadDisconnectState',
+  lgpPwrStateInputBrkrState => '1.3.6.1.4.1.476.1.42.3.5.3.44',
+  lgpPwrStateInputBrkrStateDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrStateInputBrkrState',
+  lgpPwrStateTrapFilterBrkrState => '1.3.6.1.4.1.476.1.42.3.5.3.45',
+  lgpPwrStateTrapFilterBrkrStateDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrStateTrapFilterBrkrState',
+  lgpPwrStateInvOutputBrkrState => '1.3.6.1.4.1.476.1.42.3.5.3.46',
+  lgpPwrStateInvOutputBrkrStateDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrStateInvOutputBrkrState',
+  lgpPwrStateIntBypassBrkrState => '1.3.6.1.4.1.476.1.42.3.5.3.47',
+  lgpPwrStateIntBypassBrkrStateDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrStateIntBypassBrkrState',
+  lgpPwrStateBypassIsolBrkrState => '1.3.6.1.4.1.476.1.42.3.5.3.48',
+  lgpPwrStateBypassIsolBrkrStateDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrStateBypassIsolBrkrState',
+  lgpPwrStateRectifierIsolBrkrState => '1.3.6.1.4.1.476.1.42.3.5.3.49',
+  lgpPwrStateRectifierIsolBrkrStateDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrStateRectifierIsolBrkrState',
+  lgpPwrStateMaintBypassBrkrState => '1.3.6.1.4.1.476.1.42.3.5.3.50',
+  lgpPwrStateMaintBypassBrkrStateDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrStateMaintBypassBrkrState',
+  lgpPwrStateMaintIsolBrkrState => '1.3.6.1.4.1.476.1.42.3.5.3.51',
+  lgpPwrStateMaintIsolBrkrStateDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrStateMaintIsolBrkrState',
+  lgpPwrStateOutStaticSwState => '1.3.6.1.4.1.476.1.42.3.5.3.52',
+  lgpPwrStateOutStaticSwStateDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrStateOutStaticSwState',
+  lgpPwrStateModuleOutBrkrState => '1.3.6.1.4.1.476.1.42.3.5.3.53',
+  lgpPwrStateModuleOutBrkrStateDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrStateModuleOutBrkrState',
+  lgpPwrBypassReXfrRemainTime => '1.3.6.1.4.1.476.1.42.3.5.3.54',
+  lgpPwrStateUpsOutputSource => '1.3.6.1.4.1.476.1.42.3.5.3.55',
+  lgpPwrStateUpsOutputSourceDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrStateUpsOutputSource',
+  lgpPwrStateLoadBusSynchronization => '1.3.6.1.4.1.476.1.42.3.5.3.56',
+  lgpPwrStateLoadBusSynchronizationDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrStateLoadBusSynchronization',
+  lgpPwrStateCircuitBrkrStateGroup => '1.3.6.1.4.1.476.1.42.3.5.3.57',
+  lgpPwrStateSource1InputBrkrState => '1.3.6.1.4.1.476.1.42.3.5.3.57.1',
+  lgpPwrStateSource1InputBrkrStateDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrStateSource1InputBrkrState',
+  lgpPwrStateSource2InputBrkrState => '1.3.6.1.4.1.476.1.42.3.5.3.57.2',
+  lgpPwrStateSource2InputBrkrStateDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrStateSource2InputBrkrState',
+  lgpPwrStateSource1BypassBrkrState => '1.3.6.1.4.1.476.1.42.3.5.3.57.3',
+  lgpPwrStateSource1BypassBrkrStateDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrStateSource1BypassBrkrState',
+  lgpPwrStateSource2BypassBrkrState => '1.3.6.1.4.1.476.1.42.3.5.3.57.4',
+  lgpPwrStateSource2BypassBrkrStateDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrStateSource2BypassBrkrState',
+  lgpPwrStateOutputBrkrState => '1.3.6.1.4.1.476.1.42.3.5.3.57.5',
+  lgpPwrStateOutputBrkrStateDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrStateOutputBrkrState',
+  lgpPwrStateAuxOutputBrkrState => '1.3.6.1.4.1.476.1.42.3.5.3.57.6',
+  lgpPwrStateAuxOutputBrkrStateDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrStateAuxOutputBrkrState',
+  lgpPwrStateSource1PduInputBrkrState => '1.3.6.1.4.1.476.1.42.3.5.3.57.7',
+  lgpPwrStateSource1PduInputBrkrStateDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrStateSource1PduInputBrkrState',
+  lgpPwrStateSource2PduInputBrkrState => '1.3.6.1.4.1.476.1.42.3.5.3.57.8',
+  lgpPwrStateSource2PduInputBrkrStateDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrStateSource2PduInputBrkrState',
   lgpPwrSettings => '1.3.6.1.4.1.476.1.42.3.5.4',
   lgpPwrPreferredSource => '1.3.6.1.4.1.476.1.42.3.5.4.1',
   lgpPwrLoadOnSource => '1.3.6.1.4.1.476.1.42.3.5.4.2',
@@ -232,6 +320,22 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'LIEBERT-GP-POWER-MIB'
   lgpPwrTopMaximumFrameCapacity => '1.3.6.1.4.1.476.1.42.3.5.7.6',
   lgpPwrTopRedundantControlModules => '1.3.6.1.4.1.476.1.42.3.5.7.7',
   lgpPwrTopRedundantControlModulesDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrTopRedundantControlModules',
+  lgpPwrInputIsolationTransformerInstalled => '1.3.6.1.4.1.476.1.42.3.5.7.8',
+  lgpPwrInputIsolationTransformerInstalledDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrInputIsolationTransformerInstalled',
+  lgpPwrStateStaticSwitchType => '1.3.6.1.4.1.476.1.42.3.5.7.9',
+  lgpPwrStateStaticSwitchTypeDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrStateStaticSwitchType',
+  lgpPwrStateModuleType => '1.3.6.1.4.1.476.1.42.3.5.7.10',
+  lgpPwrStateModuleTypeDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrStateModuleType',
+  lgpPwrStateBypassInputConfig => '1.3.6.1.4.1.476.1.42.3.5.7.11',
+  lgpPwrStateBypassInputConfigDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrStateBypassInputConfig',
+  lgpPwrStateOutputConfig => '1.3.6.1.4.1.476.1.42.3.5.7.12',
+  lgpPwrStateOutputConfigDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrStateOutputConfig',
+  lgpPwrRectifierPassiveFilterInstalled => '1.3.6.1.4.1.476.1.42.3.5.7.13',
+  lgpPwrRectifierPassiveFilterInstalledDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrRectifierPassiveFilterInstalled',
+  lgpPwrRectifierTrapInstalled => '1.3.6.1.4.1.476.1.42.3.5.7.14',
+  lgpPwrRectifierTrapInstalledDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrRectifierTrapInstalled',
+  lgpPwrRectifierActiveFilterInstalled => '1.3.6.1.4.1.476.1.42.3.5.7.15',
+  lgpPwrRectifierActiveFilterInstalledDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrRectifierActiveFilterInstalled',
   lgpPwrStatistic => '1.3.6.1.4.1.476.1.42.3.5.8',
   lgpPwrBrownOutCount => '1.3.6.1.4.1.476.1.42.3.5.8.1',
   lgpPwrBlackOutCount => '1.3.6.1.4.1.476.1.42.3.5.8.2',
@@ -246,47 +350,123 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'LIEBERT-GP-POWER-MIB'
   lgpPwrSysCapacity => '1.3.6.1.4.1.476.1.42.3.5.9.1',
   lgpPwrUPSModuleMode => '1.3.6.1.4.1.476.1.42.3.5.9.2',
   lgpPwrUPSModuleModeDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrUPSModuleMode',
+  lgpPwrMaxRatedCurrent => '1.3.6.1.4.1.476.1.42.3.5.9.3',
+  lgpPwrRectifierPulseCount => '1.3.6.1.4.1.476.1.42.3.5.9.4',
+  lgpPwrRectifierPulseCountDefinition => 'LIEBERT-GP-POWER-MIB::lgpPwrRectifierPulseCount',
 };
 
 $Monitoring::GLPlugin::SNMP::MibsAndOids::definitions->{'LIEBERT-GP-POWER-MIB'} = {
-  lgpPwrRedundantSubModule => {
-    '1' => 'yes',
-    '2' => 'no',
-  },
-  lgpPwrUpsAutoRestart => {
-    '1' => 'on',
-    '2' => 'off',
-  },
   lgpPwrAutomaticBatteryTest => {
     '1' => 'on',
     '2' => 'off',
   },
-  lgpPwrBatteryChargeMode => {
-    '1' => 'float',
-    '2' => 'equalize',
-  },
   lgpPwrUpsInverterStandby => {
     '1' => 'on',
     '2' => 'off',
   },
-  lgpPwrOutputToLoadOnBypass => {
+  lgpPwrShutdownOverload => {
     '1' => 'yes',
     '2' => 'no',
   },
-  lgpPwrLoadBusSyncMode => {
-    '1' => 'master',
-    '2' => 'slave',
-    '3' => 'none',
+  lgpPwrBatteryLifeEnhancer => {
+    '1' => 'on',
+    '2' => 'off',
   },
-  lgpPwrBatteryChargeCompensating => {
+  lgpPwrStateOutputBrkrState => {
+    '1' => 'open',
+    '2' => 'closed',
+    '3' => 'notInstalled',
+  },
+  lgpPwrUpsTopLineInteractive => {
     '1' => 'yes',
     '2' => 'no',
   },
-  lgpPwrMeasurementPointPowerFactorTag => {
+  lgpPwrTopRedundantControlModules => {
+    '1' => 'yes',
+    '2' => 'no',
+  },
+  lgpPwrBatteryCabinetType => {
+    '1' => 'notSpecified',
+    '2' => 'internal',
+    '3' => 'external',
+    '4' => 'lrt',
+  },
+  lgpPwrStateMaintBypassBrkrState => {
+    '1' => 'open',
+    '2' => 'closed',
+    '3' => 'notInstalled',
+  },
+  lgpPwrParallelSystemOutputToLoadSource => {
+    '0' => 'unknown',
+    '1' => 'utility',
+    '2' => 'battery',
+    '3' => 'bypass',
+    '4' => 'none',
+  },
+  lgpPwrUpsAutoRestart => {
+    '1' => 'on',
+    '2' => 'off',
+  },
+  lgpPwrStateOutputConfig => {
+    '1' => 'singlePhase2WireL1WithReturn',
+    '2' => 'twoPhase2WireL1L2',
+    '3' => 'twoPhase3WireL1L2WithNeutral',
+    '4' => 'threePhase3WireL1L2L3',
+    '5' => 'threePhase4WireL1L2L3WithNeutral',
+  },
+  lgpPwrRectifierPulseCount => {
+    '1' => 'sixPulse',
+    '2' => 'twelvePulse',
+    '3' => 'eighteenPulse',
+    '4' => 'twentyFourPulse',
+  },
+  lgpPwrStateMaintIsolBrkrState => {
+    '1' => 'open',
+    '2' => 'closed',
+    '3' => 'notInstalled',
+  },
+  lgpPwrLineMeasurementPowerFactorTag => {
     '1' => 'leading',
     '2' => 'lagging',
   },
-  lgpPwrShutdownRemote => {
+  lgpPwrStateSource1PduInputBrkrState => {
+    '1' => 'open',
+    '2' => 'closed',
+    '3' => 'notInstalled',
+  },
+  lgpPwrStateSource1InputBrkrState => {
+    '1' => 'open',
+    '2' => 'closed',
+    '3' => 'notInstalled',
+  },
+  lgpPwrStateOutputSource => {
+    '1' => 'none',
+    '2' => 'inverter',
+    '3' => 'bypass',
+    '4' => 'maintenanceBypass',
+  },
+  lgpPwrBatteryCharger => {
+    '1' => 'on',
+    '2' => 'off',
+  },
+  lgpPwrStateStaticSwitchType => {
+    '1' => 'notApplicable',
+    '2' => 'continuousDuty',
+    '3' => 'momentaryDuty',
+  },
+  lgpPwrStateBypassInputConfig => {
+    '1' => 'singlePhase2WireL1WithReturn',
+    '2' => 'twoPhase2WireL1L2',
+    '3' => 'twoPhase3WireL1L2WithNeutral',
+    '4' => 'threePhase3WireL1L2L3',
+    '5' => 'threePhase4WireL1L2L3WithNeutral',
+  },
+  lgpPwrStateRectifierIsolBrkrState => {
+    '1' => 'open',
+    '2' => 'closed',
+    '3' => 'notInstalled',
+  },
+  lgpPwrShutdownHardware => {
     '1' => 'yes',
     '2' => 'no',
   },
@@ -298,54 +478,42 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::definitions->{'LIEBERT-GP-POWER-MIB'}
     '5' => 'systemFailure',
     '6' => 'inhibited',
   },
-  lgpPwrPowerFactorCorrection => {
+  lgpPwrShutdownInputUnderVoltage => {
+    '1' => 'yes',
+    '2' => 'no',
+  },
+  lgpPwrAutoReTransferEnabled => {
+    '0' => 'no',
+    '1' => 'yes',
+  },
+  lgpPwrBatteryChargeMode => {
+    '1' => 'float',
+    '2' => 'equalize',
+  },
+  lgpPwrStateBackfeedBrkrState => {
+    '1' => 'open',
+    '2' => 'closed',
+    '3' => 'notInstalled',
+  },
+  lgpPwrBuck => {
     '1' => 'on',
     '2' => 'off',
   },
-  lgpPwrParallelSystemOutputToLoadSource => {
-    '0' => 'unknown',
-    '1' => 'utility',
-    '2' => 'battery',
-    '3' => 'bypass',
-    '4' => 'none',
+  lgpPwrStateInverterQualification => {
+    '1' => 'fail',
+    '2' => 'marginalLow',
+    '3' => 'normal',
+    '4' => 'marginalHigh',
   },
-  lgpPwrShutdownLineSwap => {
+  lgpPwrBatteryChargeCompensating => {
     '1' => 'yes',
     '2' => 'no',
   },
-  lgpPwrOutputToLoadOnInverter => {
-    '1' => 'yes',
-    '2' => 'no',
-  },
-  lgpPwrShutdownHardware => {
-    '1' => 'yes',
-    '2' => 'no',
-  },
-  lgpPwrShutdownOverload => {
-    '1' => 'yes',
-    '2' => 'no',
-  },
-  lgpPwrBoost => {
-    '1' => 'on',
-    '2' => 'off',
-  },
-  lgpPwrBypassReady => {
-    '1' => 'yes',
-    '2' => 'no',
-  },
-  lgpPwrShutdownLowBattery => {
-    '1' => 'yes',
-    '2' => 'no',
-  },
-  lgpPwrUPSTopDualInput => {
-    '1' => 'yes',
-    '2' => 'no',
-  },
-  lgpPwrBatteryCabinetType => {
-    '1' => 'notSpecified',
-    '2' => 'internal',
-    '3' => 'external',
-    '4' => 'lrt',
+  lgpPwrStateBypassQualification => {
+    '1' => 'fail',
+    '2' => 'marginalLow',
+    '3' => 'normal',
+    '4' => 'marginalHigh',
   },
   lgpPwrUPSModuleMode => {
     '1' => 'single',
@@ -353,65 +521,37 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::definitions->{'LIEBERT-GP-POWER-MIB'}
     '3' => 'hotmaster',
     '4' => 'hotslave',
   },
+  lgpPwrRectifierActiveFilterInstalled => {
+    '1' => 'notInstalled',
+    '2' => 'installed',
+  },
+  lgpPwrStateBypassStaticSwitchState => {
+    '1' => 'on',
+    '2' => 'off',
+  },
+  lgpPwrMeasurementPointPowerFactorTag => {
+    '1' => 'leading',
+    '2' => 'lagging',
+  },
   lgpPwrBatteryTest => {
     '1' => 'start',
     '2' => 'abort',
   },
-  lgpPwrGeneratorStatus => {
-    '1' => 'connected',
-    '2' => 'disconnected',
+  lgpPwrStateLoadDisconnectState => {
+    '1' => 'open',
+    '2' => 'closed',
+    '3' => 'notInstalled',
   },
-  lgpPwrBatteryCharger => {
-    '1' => 'on',
-    '2' => 'off',
+  lgpPwrStateUpsOutputSource => {
+    '1' => 'other',
+    '2' => 'none',
+    '3' => 'normal',
+    '4' => 'bypass',
+    '5' => 'battery',
+    '6' => 'booster',
+    '7' => 'reducer',
   },
-  lgpPwrTopRedundantControlModules => {
-    '1' => 'yes',
-    '2' => 'no',
-  },
-  lgpPwrShutdownPowerFactorCorrectionFailure => {
-    '1' => 'yes',
-    '2' => 'no',
-  },
-  lgpPwrShutdownDcBusOverload => {
-    '1' => 'yes',
-    '2' => 'no',
-  },
-  lgpPwrBatteryChargeStatus => {
-    '1' => 'fullycharged',
-    '2' => 'notfullycharged',
-    '3' => 'charging',
-    '4' => 'discharging',
-  },
-  lgpPwrUpsTopOffline => {
-    '1' => 'yes',
-    '2' => 'no',
-  },
-  lgpPwrInverterReady => {
-    '1' => 'yes',
-    '2' => 'no',
-  },
-  lgpPwrShutdownOverTemperature => {
-    '1' => 'yes',
-    '2' => 'no',
-  },
-  lgpPwrBatteryLifeEnhancer => {
-    '1' => 'on',
-    '2' => 'off',
-  },
-  lgpPwrAutoReTransferEnabled => {
-    '0' => 'no',
-    '1' => 'yes',
-  },
-  lgpPwrUpsTopLineInteractive => {
-    '1' => 'yes',
-    '2' => 'no',
-  },
-  lgpPwrTopVoltageConverter => {
-    '1' => 'yes',
-    '2' => 'no',
-  },
-  lgpPwrShutdownInputUnderVoltage => {
+  lgpPwrBypassReady => {
     '1' => 'yes',
     '2' => 'no',
   },
@@ -419,10 +559,78 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::definitions->{'LIEBERT-GP-POWER-MIB'}
     '1' => 'on',
     '2' => 'off',
   },
-  lgpPwrDcToDcConverter => {
+  lgpPwrStateModuleOutBrkrState => {
+    '1' => 'open',
+    '2' => 'closed',
+    '3' => 'notInstalled',
+  },
+  lgpPwrBatteryCapacityStatus => {
+    '1' => 'unknown',
+    '2' => 'batteryNormal',
+    '3' => 'batteryLow',
+    '4' => 'batteryDepleted',
+  },
+  lgpPwrGeneratorStatus => {
+    '1' => 'connected',
+    '2' => 'disconnected',
+  },
+  lgpPwrUpsTopOffline => {
+    '1' => 'yes',
+    '2' => 'no',
+  },
+  lgpPwrStateInputQualification => {
+    '1' => 'fail',
+    '2' => 'marginalLow',
+    '3' => 'normal',
+    '4' => 'marginalHigh',
+  },
+  lgpPwrStateSource2InputBrkrState => {
+    '1' => 'open',
+    '2' => 'closed',
+    '3' => 'notInstalled',
+  },
+  lgpPwrRectifierTrapInstalled => {
+    '1' => 'notInstalled',
+    '2' => 'installed',
+  },
+  lgpPwrRectifierPassiveFilterInstalled => {
+    '1' => 'notInstalled',
+    '2' => 'installed',
+  },
+  lgpPwrStateModuleType => {
+    '1' => 'singleModuleSystem',
+    '2' => 'module1plus1',
+    '3' => 'module1plusN',
+    '4' => 'moduleNplus1',
+    '5' => 'systemControlCabinet',
+    '6' => 'mainStaticSwitch',
+  },
+  lgpPwrTopFrequencyConverter => {
+    '1' => 'yes',
+    '2' => 'no',
+  },
+  lgpPwrStateIntBypassBrkrState => {
+    '1' => 'open',
+    '2' => 'closed',
+    '3' => 'notInstalled',
+  },
+  lgpPwrStateInverterState => {
     '1' => 'on',
     '2' => 'off',
   },
+  lgpPwrRedundantSubModule => {
+    '1' => 'yes',
+    '2' => 'no',
+  },
+  lgpPwrStateOutStaticSwState => {
+    '1' => 'off',
+    '2' => 'on',
+    '3' => 'notInstalled',
+  },
+  lgpPwrUPSTopDualInput => {
+    '1' => 'yes',
+    '2' => 'no',
+  },
   lgpPwrRotaryBreakerStatus => {
     '1' => 'unknown',
     '2' => 'closed',
@@ -431,15 +639,46 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::definitions->{'LIEBERT-GP-POWER-MIB'}
     '5' => 'bypass',
     '6' => 'maintenance',
   },
-  lgpPwrTopFrequencyConverter => {
-    '1' => 'yes',
-    '2' => 'no',
-  },
-  lgpPwrBuck => {
+  lgpPwrDcToDcConverter => {
     '1' => 'on',
     '2' => 'off',
   },
-  lgpPwrShutdownOutputShort => {
+  lgpPwrLoadBusSyncMode => {
+    '1' => 'master',
+    '2' => 'slave',
+    '3' => 'none',
+  },
+  lgpPwrShutdownDcBusOverload => {
+    '1' => 'yes',
+    '2' => 'no',
+  },
+  lgpPwrStateRectifierState => {
+    '1' => 'on',
+    '2' => 'off',
+  },
+  lgpPwrShutdownRemote => {
+    '1' => 'yes',
+    '2' => 'no',
+  },
+  lgpPwrBatteryCircuitBreakerState => {
+    '0' => 'unknown',
+    '1' => 'open',
+    '2' => 'closed',
+  },
+  lgpPwrStateInputBrkrState => {
+    '1' => 'open',
+    '2' => 'closed',
+    '3' => 'notInstalled',
+  },
+  lgpPwrShutdownOverTemperature => {
+    '1' => 'yes',
+    '2' => 'no',
+  },
+  lgpPwrOutputToLoadOnBypass => {
+    '1' => 'yes',
+    '2' => 'no',
+  },
+  lgpPwrShutdownLineSwap => {
     '1' => 'yes',
     '2' => 'no',
   },
@@ -448,8 +687,103 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::definitions->{'LIEBERT-GP-POWER-MIB'}
     '2' => 'off',
     '3' => 'default',
   },
-  lgpPwrLineMeasurementPowerFactorTag => {
-    '1' => 'leading',
-    '2' => 'lagging',
+  lgpPwrOutputToLoadOnInverter => {
+    '1' => 'yes',
+    '2' => 'no',
+  },
+  lgpPwrBoost => {
+    '1' => 'on',
+    '2' => 'off',
+  },
+  lgpPwrShutdownOutputShort => {
+    '1' => 'yes',
+    '2' => 'no',
+  },
+  lgpPwrShutdownLowBattery => {
+    '1' => 'yes',
+    '2' => 'no',
+  },
+  lgpPwrShutdownPowerFactorCorrectionFailure => {
+    '1' => 'yes',
+    '2' => 'no',
+  },
+  lgpPwrStateOutQualification => {
+    '1' => 'fail',
+    '2' => 'marginalLow',
+    '3' => 'normal',
+    '4' => 'marginalHigh',
+  },
+  lgpPwrStateInputSource => {
+    '1' => 'none',
+    '2' => 'utility',
+    '3' => 'generator',
+  },
+  lgpPwrStateBypassIsolBrkrState => {
+    '1' => 'open',
+    '2' => 'closed',
+    '3' => 'notInstalled',
+  },
+  lgpPwrStateSource2BypassBrkrState => {
+    '1' => 'open',
+    '2' => 'closed',
+    '3' => 'notInstalled',
+  },
+  lgpPwrStateTrapFilterBrkrState => {
+    '1' => 'open',
+    '2' => 'closed',
+    '3' => 'notInstalled',
+  },
+  lgpPwrBatteryChargeStatus => {
+    '1' => 'fullycharged',
+    '2' => 'notfullycharged',
+    '3' => 'charging',
+    '4' => 'discharging',
+  },
+  lgpPwrStateDCBusQualification => {
+    '1' => 'fail',
+    '2' => 'marginalLow',
+    '3' => 'normal',
+    '4' => 'marginalHigh',
+  },
+  lgpPwrInputIsolationTransformerInstalled => {
+    '1' => 'notInstalled',
+    '2' => 'installed',
+  },
+  lgpPwrInverterReady => {
+    '1' => 'yes',
+    '2' => 'no',
+  },
+  lgpPwrStateSource2PduInputBrkrState => {
+    '1' => 'open',
+    '2' => 'closed',
+    '3' => 'notInstalled',
+  },
+  lgpPwrStateSource1BypassBrkrState => {
+    '1' => 'open',
+    '2' => 'closed',
+    '3' => 'notInstalled',
+  },
+  lgpPwrStateLoadBusSynchronization => {
+    '0' => 'unknown',
+    '1' => 'active',
+    '2' => 'abnormal',
+  },
+  lgpPwrTopVoltageConverter => {
+    '1' => 'yes',
+    '2' => 'no',
+  },
+  lgpPwrPowerFactorCorrection => {
+    '1' => 'on',
+    '2' => 'off',
+  },
+  lgpPwrStateAuxOutputBrkrState => {
+    '1' => 'open',
+    '2' => 'closed',
+    '3' => 'notInstalled',
+  },
+  lgpPwrStateInvOutputBrkrState => {
+    '1' => 'open',
+    '2' => 'closed',
+    '3' => 'notInstalled',
   },
 };
